/*
 *	file:		ParanoiaMainForm.java
 * project:	Paranoia
 * content:	
 * updated:	Sep. 08. 2002
 *
 */

package org.mulliner.paranoia;

  
import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;
import java.util.*;


public class ParanoiaMainForm extends Form implements CommandListener, Backable
{
	private static final Command[] COMMANDS = 
	{
		new Command("Compute", Command.OK, 1),
		new Command("Close Menu", Command.OK, 2),
		new Command("About", Command.SCREEN, 3),
		new Command("Help", Command.SCREEN, 4),
		new Command("Exit", Command.STOP, 5)
	};

	private TextField seqField;
	private TextField seedField;
	private TextField passField;
	private Display display;
	private ChoiceGroup hashGroup;
	private Quitable winQuit;
	private ParanoiaOTP otp = new ParanoiaOTP();
	private ParanoiaShowOTPForm showOTP = new ParanoiaShowOTPForm(otp);
	private ParanoiaAbout about = new ParanoiaAbout();
	private ParanoiaHelp help = new ParanoiaHelp();


	public ParanoiaMainForm()
	{
		super("Paranoia OTP-Gen");
	
		String[] hashLabels = { "MD5", "MD4", "SHA-1" };
		hashGroup = new ChoiceGroup("HASH Type", ChoiceGroup.EXCLUSIVE, hashLabels, null);
		hashGroup.setSelectedIndex(0, true);
		append(hashGroup);
		
		seqField = new TextField("Sequence", "", 4, TextField.NUMERIC);
		append(seqField);
		seedField = new TextField("Seed", "", 16, TextField.ANY);
		append(seedField);
		passField = new TextField("PassPhrase", "", 63, TextField.ANY);
		append(passField);
		
		
		// add commands
		for (int i = 0; i < COMMANDS.length; i++) {
			addCommand(COMMANDS[i]);
		}
	}

	public void commandAction(Command cmd, Displayable s)
	{
		if (cmd == COMMANDS[0]) {
			
			otp.setSequence(Integer.valueOf(seqField.getString()).intValue());
			otp.setHashType(hashGroup.getSelectedIndex());
			otp.setSeed(seedField.getString());
			otp.setPassPhrase(passField.getString());
		
			showOTP.activate(display, this);
		}
		else if (cmd == COMMANDS[2]) {
			about.activate(display, this);
		}
		else if (cmd == COMMANDS[3]) {
			help.activate(display, this);
		}
		else if (cmd == COMMANDS[4]) {
			winQuit.quit();
		}
	}
	
	public void activate(Display d, Quitable q)
	{
		display = d;
		winQuit = q;
		
		display.setCurrent(this);
		setCommandListener(this);
	}
	
	public void show()
	{
		display.setCurrent(this);
		setCommandListener(this);
	}
}
