/*
 * file:    ParanoiaOTP.java
 * project:	Paranoia
 * content:	main stuff
 * updated:	Sep. 08. 2002
 *
 * Copyright (c) Collin R. Mulliner <wj@mulliner.org>
 * www.mulliner.org/wj/
 *
 * license: GPL
 * 
 */

package org.mulliner.paranoia;

public class ParanoiaOTP
{
	private String Seed;
	private String PassPhrase;
	private int Sequence;
	private int HashType;	// 0 = MD5, 1 = MD4, 2 = SHA1
	private byte[] CurrentKey;
	private boolean filled;
	
	private static String[] SKEYWords = new String[] {
  "A",    "ABE",   "ACE",   "ACT",   "AD",    "ADA",   "ADD",
"AGO",   "AID",  "AIM",   "AIR",   "ALL",   "ALP",   "AM",    "AMY",
"AN",    "ANA",  "AND",   "ANN",   "ANT",   "ANY",   "APE",   "APS",
"APT",   "ARC",  "ARE",   "ARK",   "ARM",   "ART",   "AS",    "ASH",
"ASK",   "AT",   "ATE",   "AUG",   "AUK",   "AVE",   "AWE",   "AWK",
"AWL",   "AWN",  "AX",    "AYE",   "BAD",   "BAG",   "BAH",   "BAM",
"BAN",   "BAR",  "BAT",   "BAY",   "BE",    "BED",   "BEE",   "BEG",
"BEN",   "BET",  "BEY",   "BIB",   "BID",   "BIG",   "BIN",   "BIT",
"BOB",   "BOG",  "BON",   "BOO",   "BOP",   "BOW",   "BOY",   "BUB",
"BUD",   "BUG",  "BUM",   "BUN",   "BUS",   "BUT",   "BUY",   "BY",
"BYE",   "CAB",  "CAL",   "CAM",   "CAN",   "CAP",   "CAR",   "CAT",
"CAW",   "COD",  "COG",   "COL",   "CON",   "COO",   "COP",   "COT",
"COW",   "COY",  "CRY",   "CUB",   "CUE",   "CUP",   "CUR",   "CUT",
"DAB",   "DAD",  "DAM",   "DAN",   "DAR",   "DAY",   "DEE",   "DEL",
"DEN",   "DES",  "DEW",   "DID",   "DIE",   "DIG",   "DIN",   "DIP",
"DO",    "DOE",  "DOG",   "DON",   "DOT",   "DOW",   "DRY",   "DUB",
"DUD",   "DUE",  "DUG",   "DUN",   "EAR",   "EAT",   "ED",    "EEL",
"EGG",   "EGO",  "ELI",   "ELK",   "ELM",   "ELY",   "EM",    "END",
"EST",   "ETC",  "EVA",   "EVE",   "EWE",   "EYE",   "FAD",   "FAN",
"FAR",   "FAT",  "FAY",   "FED",   "FEE",   "FEW",   "FIB",   "FIG",
"FIN",   "FIR",  "FIT",   "FLO",   "FLY",   "FOE",   "FOG",   "FOR",
"FRY",   "FUM",  "FUN",   "FUR",   "GAB",   "GAD",   "GAG",   "GAL",
"GAM",   "GAP",  "GAS",   "GAY",   "GEE",   "GEL",   "GEM",   "GET",
"GIG",   "GIL",  "GIN",   "GO",    "GOT",   "GUM",   "GUN",   "GUS",
"GUT",   "GUY",  "GYM",   "GYP",   "HA",    "HAD",   "HAL",   "HAM",
"HAN",   "HAP",  "HAS",   "HAT",   "HAW",   "HAY",   "HE",    "HEM",
"HEN",   "HER",  "HEW",   "HEY",   "HI",    "HID",   "HIM",   "HIP",
"HIS",   "HIT",  "HO",    "HOB",   "HOC",   "HOE",   "HOG",   "HOP",
"HOT",   "HOW",  "HUB",   "HUE",   "HUG",   "HUH",   "HUM",   "HUT",
"I",     "ICY",  "IDA",   "IF",    "IKE",   "ILL",   "INK",   "INN",
"IO",    "ION",  "IQ",    "IRA",   "IRE",   "IRK",   "IS",    "IT",
"ITS",   "IVY",  "JAB",   "JAG",   "JAM",   "JAN",   "JAR",   "JAW",
"JAY",   "JET",  "JIG",   "JIM",   "JO",    "JOB",   "JOE",   "JOG",
"JOT",   "JOY",  "JUG",   "JUT",   "KAY",   "KEG",   "KEN",   "KEY",
"KID",   "KIM",  "KIN",   "KIT",   "LA",    "LAB",   "LAC",   "LAD",
"LAG",   "LAM",  "LAP",   "LAW",   "LAY",   "LEA",   "LED",   "LEE",
"LEG",   "LEN",  "LEO",   "LET",   "LEW",   "LID",   "LIE",   "LIN",
"LIP",   "LIT",  "LO",    "LOB",   "LOG",   "LOP",   "LOS",   "LOT",
"LOU",   "LOW",  "LOY",   "LUG",   "LYE",   "MA",    "MAC",   "MAD",
"MAE",   "MAN",  "MAO",   "MAP",   "MAT",   "MAW",   "MAY",   "ME",
"MEG",   "MEL",  "MEN",   "MET",   "MEW",   "MID",   "MIN",   "MIT",
"MOB",   "MOD",  "MOE",   "MOO",   "MOP",   "MOS",   "MOT",   "MOW",
"MUD",   "MUG",  "MUM",   "MY",    "NAB",   "NAG",   "NAN",   "NAP",
"NAT",   "NAY",  "NE",    "NED",   "NEE",   "NET",   "NEW",   "NIB",
"NIL",   "NIP",  "NIT",   "NO",    "NOB",   "NOD",   "NON",   "NOR",
"NOT",   "NOV",  "NOW",   "NU",    "NUN",   "NUT",   "O",     "OAF",
"OAK",   "OAR",  "OAT",   "ODD",   "ODE",   "OF",    "OFF",   "OFT",
"OH",    "OIL",  "OK",    "OLD",   "ON",    "ONE",   "OR",    "ORB",
"ORE",   "ORR",  "OS",    "OTT",   "OUR",   "OUT",   "OVA",   "OW",
"OWE",   "OWL",  "OWN",   "OX",    "PA",    "PAD",   "PAL",   "PAM",
"PAN",   "PAP",  "PAR",   "PAT",   "PAW",   "PAY",   "PEA",   "PEG",
"PEN",   "PEP",  "PER",   "PET",   "PEW",   "PHI",   "PI",    "PIE",
"PIN",   "PIT",  "PLY",   "PO",    "POD",   "POE",   "POP",   "POT",
"POW",   "PRO",  "PRY",   "PUB",   "PUG",   "PUN",   "PUP",   "PUT",
"QUO",   "RAG",  "RAM",   "RAN",   "RAP",   "RAT",   "RAW",   "RAY",
"REB",   "RED",  "REP",   "RET",   "RIB",   "RID",   "RIG",   "RIM",
"RIO",   "RIP",  "ROB",   "ROD",   "ROE",   "RON",   "ROT",   "ROW",
"ROY",   "RUB",  "RUE",   "RUG",   "RUM",   "RUN",   "RYE",   "SAC",
"SAD",   "SAG",  "SAL",   "SAM",   "SAN",   "SAP",   "SAT",   "SAW",
"SAY",   "SEA",  "SEC",   "SEE",   "SEN",   "SET",   "SEW",   "SHE",
"SHY",   "SIN",  "SIP",   "SIR",   "SIS",   "SIT",   "SKI",   "SKY",
"SLY",   "SO",   "SOB",   "SOD",   "SON",   "SOP",   "SOW",   "SOY",
"SPA",   "SPY",  "SUB",   "SUD",   "SUE",   "SUM",   "SUN",   "SUP",
"TAB",   "TAD",  "TAG",   "TAN",   "TAP",   "TAR",   "TEA",   "TED",
"TEE",   "TEN",  "THE",   "THY",   "TIC",   "TIE",   "TIM",   "TIN",
"TIP",   "TO",   "TOE",   "TOG",   "TOM",   "TON",   "TOO",   "TOP",
"TOW",   "TOY",  "TRY",   "TUB",   "TUG",   "TUM",   "TUN",   "TWO",
"UN",    "UP",   "US",    "USE",   "VAN",   "VAT",   "VET",   "VIE",
"WAD",   "WAG",  "WAR",   "WAS",   "WAY",   "WE",    "WEB",   "WED",
"WEE",   "WET",  "WHO",   "WHY",   "WIN",   "WIT",   "WOK",   "WON",
"WOO",   "WOW",  "WRY",   "WU",    "YAM",   "YAP",   "YAW",   "YE",
"YEA",   "YES",  "YET",   "YOU",   "ABED",  "ABEL",  "ABET",  "ABLE",
"ABUT", "ACHE", "ACID", "ACME", "ACRE", "ACTA", "ACTS", "ADAM", "ADDS", 
"ADEN", "AFAR", "AFRO", "AGEE", "AHEM", "AHOY", "AIDA", "AIDE", "AIDS", 
"AIRY", "AJAR", "AKIN", "ALAN", "ALEC", "ALGA", "ALIA", "ALLY", "ALMA", 
"ALOE", "ALSO", "ALTO", "ALUM", "ALVA", "AMEN", "AMES", "AMID", "AMMO", 
"AMOK", "AMOS", "AMRA", "ANDY", "ANEW", "ANNA", "ANNE", "ANTE", "ANTI", 
"AQUA", "ARAB", "ARCH", "AREA", "ARGO", "ARID", "ARMY", "ARTS", "ARTY", 
"ASIA", "ASKS", "ATOM", "AUNT", "AURA", "AUTO", "AVER", "AVID", "AVIS", 
"AVON", "AVOW", "AWAY", "AWRY", "BABE", "BABY", "BACH", "BACK", "BADE", 
"BAIL", "BAIT", "BAKE", "BALD", "BALE", "BALI", "BALK", "BALL", "BALM", 
"BAND", "BANE", "BANG", "BANK", "BARB", "BARD", "BARE", "BARK", "BARN", 
"BARR", "BASE", "BASH", "BASK", "BASS", "BATE", "BATH", "BAWD", "BAWL", 
"BEAD", "BEAK", "BEAM", "BEAN", "BEAR", "BEAT", "BEAU", "BECK", "BEEF", 
"BEEN", "BEER", "BEET", "BELA", "BELL", "BELT", "BEND", "BENT", "BERG",
"BERN", "BERT", "BESS", "BEST", "BETA", "BETH", "BHOY", "BIAS", "BIDE",
"BIEN", "BILE", "BILK", "BILL", "BIND", "BING", "BIRD", "BITE", "BITS", 
"BLAB", "BLAT", "BLED", "BLEW", "BLOB", "BLOC", "BLOT", "BLOW", "BLUE", 
"BLUM", "BLUR", "BOAR", "BOAT", "BOCA", "BOCK", "BODE", "BODY", "BOGY", 
"BOHR", "BOIL", "BOLD", "BOLO", "BOLT", "BOMB", "BONA", "BOND", "BONE", 
"BONG", "BONN", "BONY", "BOOK", "BOOM", "BOON", "BOOT", "BORE", "BORG", 
"BORN", "BOSE", "BOSS", "BOTH", "BOUT", "BOWL", "BOYD", "BRAD", "BRAE", 
"BRAG", "BRAN", "BRAY", "BRED", "BREW", "BRIG", "BRIM", "BROW", "BUCK", 
"BUDD", "BUFF", "BULB", "BULK", "BULL", "BUNK", "BUNT", "BUOY", "BURG", 
"BURL", "BURN", "BURR", "BURT", "BURY", "BUSH", "BUSS", "BUST", "BUSY", 
"BYTE", "CADY", "CAFE", "CAGE", "CAIN", "CAKE", "CALF", "CALL", "CALM", 
"CAME", "CANE", "CANT", "CARD", "CARE", "CARL", "CARR", "CART", "CASE", 
"CASH", "CASK", "CAST", "CAVE", "CEIL", "CELL", "CENT", "CERN", "CHAD", 
"CHAR", "CHAT", "CHAW", "CHEF", "CHEN", "CHEW", 
"CHIC", "CHIN", "CHOU", "CHOW", "CHUB", "CHUG", "CHUM", "CITE", "CITY", 
"CLAD", "CLAM", "CLAN", "CLAW", "CLAY", "CLOD", "CLOG", "CLOT", "CLUB", 
"CLUE", "COAL", "COAT", "COCA", "COCK", "COCO", "CODA", "CODE", "CODY", 
"COED", "COIL", "COIN", "COKE", "COLA", "COLD", "COLT", "COMA", "COMB", 
"COME", "COOK", "COOL", "COON", "COOT", "CORD", "CORE", "CORK", "CORN", 
"COST", "COVE", "COWL", "CRAB", "CRAG", "CRAM", "CRAY", "CREW", "CRIB", 
"CROW", "CRUD", "CUBA", "CUBE", "CUFF", "CULL", "CULT", "CUNY", "CURB", 
"CURD", "CURE", "CURL", "CURT", "CUTS", "DADE", "DALE", "DAME", "DANA", 
"DANE", "DANG", "DANK", "DARE", "DARK", "DARN", "DART", "DASH", "DATA",
"DATE", "DAVE", "DAVY", "DAWN", "DAYS", "DEAD", "DEAF", "DEAL", "DEAN",
"DEAR", "DEBT", "DECK", "DEED", "DEEM", "DEER", "DEFT", "DEFY", "DELL", 
"DENT", "DENY", "DESK", "DIAL", "DICE", "DIED", "DIET", "DIME", "DINE", 
"DING", "DINT", "DIRE", "DIRT", "DISC", "DISH", "DISK", "DIVE", "DOCK", 
"DOES", "DOLE", "DOLL", "DOLT", "DOME", "DONE", "DOOM", "DOOR", "DORA", 
"DOSE", "DOTE", "DOUG", "DOUR", "DOVE", "DOWN", "DRAB", "DRAG", "DRAM", 
"DRAW", "DREW", "DRUB", "DRUG", "DRUM", "DUAL", "DUCK", "DUCT", "DUEL", 
"DUET", "DUKE", "DULL", "DUMB", "DUNE", "DUNK", "DUSK", "DUST", "DUTY", 
"EACH", "EARL", "EARN", "EASE", "EAST", "EASY", "EBEN", "ECHO", "EDDY", 
"EDEN", "EDGE", "EDGY", "EDIT", "EDNA", "EGAN", "ELAN", "ELBA", "ELLA", 
"ELSE", "EMIL", "EMIT", "EMMA", "ENDS", "ERIC", "EROS", "EVEN", "EVER", 
"EVIL", "EYED", "FACE", "FACT", "FADE", "FAIL", "FAIN", "FAIR", "FAKE", 
"FALL", "FAME", "FANG", "FARM", "FAST", "FATE", "FAWN", "FEAR", "FEAT", 
"FEED", "FEEL", "FEET", "FELL", "FELT", "FEND", "FERN", "FEST", "FEUD", 
"FIEF", "FIGS", "FILE", "FILL", "FILM", "FIND", "FINE", "FINK", "FIRE", 
"FIRM", "FISH", "FISK", "FIST", "FITS", "FIVE", "FLAG", "FLAK", "FLAM", 
"FLAT", "FLAW", "FLEA", "FLED", "FLEW", "FLIT", "FLOC", "FLOG", "FLOW", 
"FLUB", "FLUE", "FOAL", "FOAM", "FOGY", "FOIL", "FOLD", "FOLK", "FOND", 
"FONT", "FOOD", "FOOL", "FOOT", "FORD", "FORE", "FORK", "FORM", "FORT", 
"FOSS", "FOUL", "FOUR", "FOWL", "FRAU", "FRAY", "FRED", "FREE", "FRET", 
"FREY", "FROG", "FROM", "FUEL", "FULL", "FUME", "FUND", "FUNK", "FURY", 
"FUSE", "FUSS", "GAFF", "GAGE", "GAIL", "GAIN", "GAIT", "GALA", "GALE", 
"GALL", "GALT", "GAME", "GANG", "GARB", "GARY", "GASH", "GATE", "GAUL", 
"GAUR", "GAVE", "GAWK", "GEAR", "GELD", "GENE", "GENT", "GERM", "GETS", 
"GIBE", "GIFT", "GILD", "GILL", "GILT", "GINA", "GIRD", "GIRL", "GIST", 
"GIVE", "GLAD", "GLEE", "GLEN", "GLIB", "GLOB", "GLOM", "GLOW", "GLUE", 
"GLUM", "GLUT", "GOAD", "GOAL", "GOAT", "GOER", "GOES", "GOLD", "GOLF", 
"GONE", "GONG", "GOOD", "GOOF", "GORE", "GORY", "GOSH", "GOUT", "GOWN", 
"GRAB", "GRAD", "GRAY", "GREG", "GREW", "GREY", "GRID", "GRIM", "GRIN", 
"GRIT", "GROW", "GRUB", "GULF", "GULL", "GUNK", "GURU", "GUSH", "GUST", 
"GWEN", "GWYN", "HAAG", "HAAS", "HACK", "HAIL", "HAIR", "HALE", "HALF", 
"HALL", "HALO", "HALT", "HAND", "HANG", "HANK", "HANS", "HARD", "HARK", 
"HARM", "HART", "HASH", "HAST", "HATE", "HATH", "HAUL", "HAVE", "HAWK", 
"HAYS", "HEAD", "HEAL", "HEAR", "HEAT", "HEBE", 
"HECK", "HEED", "HEEL", "HEFT", "HELD", "HELL", "HELM", "HERB", "HERD", 
"HERE", "HERO", "HERS", "HESS", "HEWN", "HICK", "HIDE", "HIGH", "HIKE", 
"HILL", "HILT", "HIND", "HINT", "HIRE", "HISS", "HIVE", "HOBO", "HOCK", 
"HOFF", "HOLD", "HOLE", "HOLM", "HOLT", "HOME", "HONE", "HONK", "HOOD", 
"HOOF", "HOOK", "HOOT", "HORN", "HOSE", "HOST", "HOUR", "HOVE", "HOWE", 
"HOWL", "HOYT", "HUCK", "HUED", "HUFF", "HUGE", "HUGH", "HUGO", "HULK", 
"HULL", "HUNK", "HUNT", "HURD", "HURL", "HURT", "HUSH", "HYDE", "HYMN", 
"IBIS", "ICON", "IDEA", "IDLE", "IFFY", "INCA", "INCH", "INTO", "IONS", 
"IOTA", "IOWA", "IRIS", "IRMA", "IRON", "ISLE", "ITCH", "ITEM", "IVAN", 
"JACK", "JADE", "JAIL", "JAKE", "JANE", "JAVA", "JEAN", "JEFF", "JERK", 
"JESS", "JEST", "JIBE", "JILL", "JILT", "JIVE", "JOAN", "JOBS", "JOCK", 
"JOEL", "JOEY", "JOHN", "JOIN", "JOKE", "JOLT", "JOVE", "JUDD", "JUDE", 
"JUDO", "JUDY", "JUJU", "JUKE", "JULY", "JUNE", "JUNK", "JUNO", "JURY", 
"JUST", "JUTE", "KAHN", "KALE", "KANE", "KANT", "KARL", "KATE", "KEEL", 
"KEEN", "KENO", "KENT", "KERN", "KERR", "KEYS", "KICK", "KILL", "KIND", 
"KING", "KIRK", "KISS", "KITE", "KLAN", "KNEE", "KNEW", "KNIT", "KNOB", 
"KNOT", "KNOW", "KOCH", "KONG", "KUDO", "KURD", "KURT", "KYLE", "LACE", 
"LACK", "LACY", "LADY", "LAID", "LAIN", "LAIR", "LAKE", "LAMB", "LAME", 
"LAND", "LANE", "LANG", "LARD", "LARK", "LASS", "LAST", "LATE", "LAUD", 
"LAVA", "LAWN", "LAWS", "LAYS", "LEAD", "LEAF", "LEAK", "LEAN", "LEAR", 
"LEEK", "LEER", "LEFT", "LEND", "LENS", "LENT", "LEON", "LESK", "LESS", 
"LEST", "LETS", "LIAR", "LICE", "LICK", "LIED", "LIEN", "LIES", "LIEU", 
"LIFE", "LIFT", "LIKE", "LILA", "LILT", "LILY", "LIMA", "LIMB", "LIME", 
"LIND", "LINE", "LINK", "LINT", "LION", "LISA", "LIST", "LIVE", "LOAD", 
"LOAF", "LOAM", "LOAN", "LOCK", "LOFT", "LOGE", "LOIS", "LOLA", "LONE", 
"LONG", "LOOK", "LOON", "LOOT", "LORD", "LORE", "LOSE", "LOSS", "LOST", 
"LOUD", "LOVE", "LOWE", "LUCK", "LUCY", "LUGE", "LUKE", "LULU", "LUND", 
"LUNG", "LURA", "LURE", "LURK", "LUSH", "LUST", "LYLE", "LYNN", "LYON", 
"LYRA", "MACE", "MADE", "MAGI", "MAID", "MAIL", "MAIN", "MAKE", "MALE", 
"MALI", "MALL", "MALT", "MANA", "MANN", "MANY", "MARC", "MARE", "MARK", 
"MARS", "MART", "MARY", "MASH", "MASK", "MASS", "MAST", "MATE", "MATH", 
"MAUL", "MAYO", "MEAD", "MEAL", "MEAN", "MEAT", "MEEK", "MEET", "MELD", 
"MELT", "MEMO", "MEND", "MENU", "MERT", "MESH", "MESS", "MICE", "MIKE", 
"MILD", "MILE", "MILK", "MILL", "MILT", "MIMI", "MIND", "MINE", "MINI", 
"MINK", "MINT", "MIRE", "MISS", "MIST", "MITE", "MITT", "MOAN", "MOAT", 
"MOCK", "MODE", "MOLD", "MOLE", "MOLL", "MOLT", "MONA", "MONK", "MONT", 
"MOOD", "MOON", "MOOR", "MOOT", "MORE", "MORN", "MORT", "MOSS", "MOST", 
"MOTH", "MOVE", "MUCH", "MUCK", "MUDD", "MUFF", "MULE", "MULL", "MURK", 
"MUSH", "MUST", "MUTE", "MUTT", "MYRA", "MYTH", "NAGY", "NAIL", "NAIR", 
"NAME", "NARY", "NASH", "NAVE", "NAVY", "NEAL", "NEAR", "NEAT", "NECK", 
"NEED", "NEIL", "NELL", "NEON", "NERO", "NESS", "NEST", "NEWS", "NEWT", 
"NIBS", "NICE", "NICK", "NILE", "NINA", "NINE", "NOAH", "NODE", "NOEL", 
"NOLL", "NONE", "NOOK", "NOON", "NORM", "NOSE", 
"NOTE", "NOUN", "NOVA", "NUDE", "NULL", "NUMB", "OATH", "OBEY", "OBOE", 
"ODIN", "OHIO", "OILY", "OINT", "OKAY", "OLAF", "OLDY", "OLGA", "OLIN", 
"OMAN", "OMEN", "OMIT", "ONCE", "ONES", "ONLY", "ONTO", "ONUS", "ORAL", 
"ORGY", "OSLO", "OTIS", "OTTO", "OUCH", "OUST", "OUTS", "OVAL", "OVEN", 
"OVER", "OWLY", "OWNS", "QUAD", "QUIT", "QUOD", "RACE", "RACK", "RACY", 
"RAFT", "RAGE", "RAID", "RAIL", "RAIN", "RAKE", "RANK", "RANT", "RARE", 
"RASH", "RATE", "RAVE", "RAYS", "READ", "REAL", "REAM", "REAR", "RECK", 
"REED", "REEF", "REEK", "REEL", "REID", "REIN", "RENA", "REND", "RENT", 
"REST", "RICE", "RICH", "RICK", "RIDE", "RIFT", "RILL", "RIME", "RING", 
"RINK", "RISE", "RISK", "RITE", "ROAD", "ROAM", "ROAR", "ROBE", "ROCK", 
"RODE", "ROIL", "ROLL", "ROME", "ROOD", "ROOF", "ROOK", "ROOM", "ROOT", 
"ROSA", "ROSE", "ROSS", "ROSY", "ROTH", "ROUT", "ROVE", "ROWE", "ROWS", 
"RUBE", "RUBY", "RUDE", "RUDY", "RUIN", "RULE", "RUNG", "RUNS", "RUNT", 
"RUSE", "RUSH", "RUSK", "RUSS", "RUST", "RUTH", "SACK", "SAFE", "SAGE", 
"SAID", "SAIL", "SALE", "SALK", "SALT", "SAME", "SAND", "SANE", "SANG", 
"SANK", "SARA", "SAUL", "SAVE", "SAYS", "SCAN", "SCAR", "SCAT", "SCOT", 
"SEAL", "SEAM", "SEAR", "SEAT", "SEED", "SEEK", "SEEM", "SEEN", "SEES", 
"SELF", "SELL", "SEND", "SENT", "SETS", "SEWN", "SHAG", "SHAM", "SHAW", 
"SHAY", "SHED", "SHIM", "SHIN", "SHOD", "SHOE", "SHOT", "SHOW", "SHUN", 
"SHUT", "SICK", "SIDE", "SIFT", "SIGH", "SIGN", "SILK", "SILL", "SILO", 
"SILT", "SINE", "SING", "SINK", "SIRE", "SITE", "SITS", "SITU", "SKAT", 
"SKEW", "SKID", "SKIM", "SKIN", "SKIT", "SLAB", "SLAM", "SLAT", "SLAY", 
"SLED", "SLEW", "SLID", "SLIM", "SLIT", "SLOB", "SLOG", "SLOT", "SLOW", 
"SLUG", "SLUM", "SLUR", "SMOG", "SMUG", "SNAG", "SNOB", "SNOW", "SNUB", 
"SNUG", "SOAK", "SOAR", "SOCK", "SODA", "SOFA", "SOFT", "SOIL", "SOLD", 
"SOME", "SONG", "SOON", "SOOT", "SORE", "SORT", "SOUL", "SOUR", "SOWN", 
"STAB", "STAG", "STAN", "STAR", "STAY", "STEM", "STEW", "STIR", "STOW", 
"STUB", "STUN", "SUCH", "SUDS", "SUIT", "SULK", "SUMS", "SUNG", "SUNK", 
"SURE", "SURF", "SWAB", "SWAG", "SWAM", "SWAN", "SWAT", "SWAY", "SWIM", 
"SWUM", "TACK", "TACT", "TAIL", "TAKE", "TALE", "TALK", "TALL", "TANK", 
"TASK", "TATE", "TAUT", "TEAL", "TEAM", "TEAR", "TECH", "TEEM", "TEEN", 
"TEET", "TELL", "TEND", "TENT", "TERM", "TERN", "TESS", "TEST", "THAN", 
"THAT", "THEE", "THEM", "THEN", "THEY", "THIN", "THIS", "THUD", "THUG", 
"TICK", "TIDE", "TIDY", "TIED", "TIER", "TILE", "TILL", "TILT", "TIME", 
"TINA", "TINE", "TINT", "TINY", "TIRE", "TOAD", "TOGO", "TOIL", "TOLD", 
"TOLL", "TONE", "TONG", "TONY", "TOOK", "TOOL", "TOOT", "TORE", "TORN", 
"TOTE", "TOUR", "TOUT", "TOWN", "TRAG", "TRAM", "TRAY", "TREE", "TREK", 
"TRIG", "TRIM", "TRIO", "TROD", "TROT", "TROY", "TRUE", "TUBA", "TUBE", 
"TUCK", "TUFT", "TUNA", "TUNE", "TUNG", "TURF", "TURN", "TUSK", "TWIG", 
"TWIN", "TWIT", "ULAN", "UNIT", "URGE", "USED", "USER", "USES", "UTAH", 
"VAIL", "VAIN", "VALE", "VARY", "VASE", "VAST", "VEAL", "VEDA", "VEIL", 
"VEIN", "VEND", "VENT", "VERB", "VERY", "VETO", "VICE", "VIEW", "VINE", 
"VISE", "VOID", "VOLT", "VOTE", "WACK", "WADE", 
"WAGE", "WAIL", "WAIT", "WAKE", "WALE", "WALK", "WALL", "WALT", "WAND", 
"WANE", "WANG", "WANT", "WARD", "WARM", "WARN", "WART", "WASH", "WAST", 
"WATS", "WATT", "WAVE", "WAVY", "WAYS", "WEAK", "WEAL", "WEAN", "WEAR", 
"WEED", "WEEK", "WEIR", "WELD", "WELL", "WELT", "WENT", "WERE", "WERT", 
"WEST", "WHAM", "WHAT", "WHEE", "WHEN", "WHET", "WHOA", "WHOM", "WICK", 
"WIFE", "WILD", "WILL", "WIND", "WINE", "WING", "WINK", "WINO", "WIRE", 
"WISE", "WISH", "WITH", "WOLF", "WONT", "WOOD", "WOOL", "WORD", "WORE", 
"WORK", "WORM", "WORN", "WOVE", "WRIT", "WYNN", "YALE", "YANG", "YANK", 
"YARD", "YARN", "YAWL", "YAWN", "YEAH", "YEAR", "YELL", "YOGA", "YOKE" };


/*
private static String[] SKEYWords2 = new String[] {
  "A",     "ABE",   "ACE",   "ACT",   "AD",    "ADA",   "ADD",
"AGO",   "AID",   "AIM",   "AIR",   "ALL",   "ALP",   "AM",    "AMY",
"AN",    "ANA",   "AND",   "ANN",   "ANT",   "ANY",   "APE",   "APS",
"APT",   "ARC",   "ARE",   "ARK",   "ARM",   "ART",   "AS",    "ASH",
"ASK",   "AT",    "ATE",   "AUG",   "AUK",   "AVE",   "AWE",   "AWK",
"AWL",   "AWN",   "AX",    "AYE",   "BAD",   "BAG",   "BAH",   "BAM",
"BAN",   "BAR",   "BAT",   "BAY",   "BE",    "BED",   "BEE",   "BEG",
"BEN",   "BET",   "BEY",   "BIB",   "BID",   "BIG",   "BIN",   "BIT",
"BOB",   "BOG",   "BON",   "BOO",   "BOP",   "BOW",   "BOY",   "BUB",
"BUD",   "BUG",   "BUM",   "BUN",   "BUS",   "BUT",   "BUY",   "BY",
"BYE",   "CAB",   "CAL",   "CAM",   "CAN",   "CAP",   "CAR",   "CAT",
"CAW",   "COD",   "COG",   "COL",   "CON",   "COO",   "COP",   "COT",
"COW",   "COY",   "CRY",   "CUB",   "CUE",   "CUP",   "CUR",   "CUT",
"DAB",   "DAD",   "DAM",   "DAN",   "DAR",   "DAY",   "DEE",   "DEL",
"DEN",   "DES",   "DEW",   "DID",   "DIE",   "DIG",   "DIN",   "DIP",
"DO",    "DOE",   "DOG",   "DON",   "DOT",   "DOW",   "DRY",   "DUB",
"DUD",   "DUE",   "DUG",   "DUN",   "EAR",   "EAT",   "ED",    "EEL",
"EGG",   "EGO",   "ELI",   "ELK",   "ELM",   "ELY",   "EM",    "END",
"EST",   "ETC",   "EVA",   "EVE",   "EWE",   "EYE",   "FAD",   "FAN",
"FAR",   "FAT",   "FAY",   "FED",   "FEE",   "FEW",   "FIB",   "FIG",
"FIN",   "FIR",   "FIT",   "FLO",   "FLY",   "FOE",   "FOG",   "FOR",
"FRY",   "FUM",   "FUN",   "FUR",   "GAB",   "GAD",   "GAG",   "GAL",
"GAM",   "GAP",   "GAS",   "GAY",   "GEE",   "GEL",   "GEM",   "GET",
"GIG",   "GIL",   "GIN",   "GO",    "GOT",   "GUM",   "GUN",   "GUS",
"GUT",   "GUY",   "GYM",   "GYP",   "HA",    "HAD",   "HAL",   "HAM",
"HAN",   "HAP",   "HAS",   "HAT",   "HAW",   "HAY",   "HE",    "HEM",
"HEN",   "HER",   "HEW",   "HEY",   "HI",    "HID",   "HIM",   "HIP",
"HIS",   "HIT",   "HO",    "HOB",   "HOC",   "HOE",   "HOG",   "HOP",
"HOT",   "HOW",   "HUB",   "HUE",   "HUG",   "HUH",   "HUM",   "HUT",
"I",     "ICY",   "IDA",   "IF",    "IKE",   "ILL",   "INK",   "INN",
"IO",    "ION",   "IQ",    "IRA",   "IRE",   "IRK",   "IS",    "IT",
"ITS",   "IVY",   "JAB",   "JAG",   "JAM",   "JAN",   "JAR",   "JAW",
"JAY",   "JET",   "JIG",   "JIM",   "JO",    "JOB",   "JOE",   "JOG",
"JOT",   "JOY",   "JUG",   "JUT",   "KAY",   "KEG",   "KEN",   "KEY",
"KID",   "KIM",   "KIN",   "KIT",   "LA",    "LAB",   "LAC",   "LAD",
"LAG",   "LAM",   "LAP",   "LAW",   "LAY",   "LEA",   "LED",   "LEE",
"LEG",   "LEN",   "LEO",   "LET",   "LEW",   "LID",   "LIE",   "LIN",
"LIP",   "LIT",   "LO",    "LOB",   "LOG",   "LOP",   "LOS",   "LOT",
"LOU",   "LOW",   "LOY",   "LUG",   "LYE",   "MA",    "MAC",   "MAD",
"MAE",   "MAN",   "MAO",   "MAP",   "MAT",   "MAW",   "MAY",   "ME",
"MEG",   "MEL",   "MEN",   "MET",   "MEW",   "MID",   "MIN",   "MIT",
"MOB",   "MOD",   "MOE",   "MOO",   "MOP",   "MOS",   "MOT",   "MOW",
"MUD",   "MUG",   "MUM",   "MY",    "NAB",   "NAG",   "NAN",   "NAP",
"NAT",   "NAY",   "NE",    "NED",   "NEE",   "NET",   "NEW",   "NIB",
"NIL",   "NIP",   "NIT",   "NO",    "NOB",   "NOD",   "NON",   "NOR",
"NOT",   "NOV",   "NOW",   "NU",    "NUN",   "NUT",   "O",     "OAF",
"OAK",   "OAR",   "OAT",   "ODD",   "ODE",   "OF",    "OFF",   "OFT",
"OH",    "OIL",   "OK",    "OLD",   "ON",    "ONE",   "OR",    "ORB",
"ORE",   "ORR",   "OS",    "OTT",   "OUR",   "OUT",   "OVA",   "OW",
"OWE",   "OWL",   "OWN",   "OX",    "PA",    "PAD",   "PAL",   "PAM",
"PAN",   "PAP",   "PAR",   "PAT",   "PAW",   "PAY",   "PEA",   "PEG",
"PEN",   "PEP",   "PER",   "PET",   "PEW",   "PHI",   "PI",    "PIE",
"PIN",   "PIT",   "PLY",   "PO",    "POD",   "POE",   "POP",   "POT",
"POW",   "PRO",   "PRY",   "PUB",   "PUG",   "PUN",   "PUP",   "PUT",
"QUO",   "RAG",   "RAM",   "RAN",   "RAP",   "RAT",   "RAW",   "RAY",
"REB",   "RED",   "REP",   "RET",   "RIB",   "RID",   "RIG",   "RIM",
"RIO",   "RIP",   "ROB",   "ROD",   "ROE",   "RON",   "ROT",   "ROW",
"ROY",   "RUB",   "RUE",   "RUG",   "RUM",   "RUN",   "RYE",   "SAC",
"SAD",   "SAG",   "SAL",   "SAM",   "SAN",   "SAP",   "SAT",   "SAW",
"SAY",   "SEA",   "SEC",   "SEE",   "SEN",   "SET",   "SEW",   "SHE",
"SHY",   "SIN",   "SIP",   "SIR",   "SIS",   "SIT",   "SKI",   "SKY",
"SLY",   "SO",    "SOB",   "SOD",   "SON",   "SOP",   "SOW",   "SOY",
"SPA",   "SPY",   "SUB",   "SUD",   "SUE",   "SUM",   "SUN",   "SUP",
"TAB",   "TAD",   "TAG",   "TAN",   "TAP",   "TAR",   "TEA",   "TED",
"TEE",   "TEN",   "THE",   "THY",   "TIC",   "TIE",   "TIM",   "TIN",
"TIP",   "TO",    "TOE",   "TOG",   "TOM",   "TON",   "TOO",   "TOP",
"TOW",   "TOY",   "TRY",   "TUB",   "TUG",   "TUM",   "TUN",   "TWO",
"UN",    "UP",    "US",    "USE",   "VAN",   "VAT",   "VET",   "VIE",
"WAD",   "WAG",   "WAR",   "WAS",   "WAY",   "WE",    "WEB",   "WED",
"WEE",   "WET",   "WHO",   "WHY",   "WIN",   "WIT",   "WOK",   "WON",
"WOO",   "WOW",   "WRY",   "WU",    "YAM",   "YAP",   "YAW",   "YE",
"YEA",   "YES",   "YET",   "YOU",   "ABED",  "ABEL",  "ABET",  "ABLE",
"ABUT",  "ACHE",  "ACID",  "ACME",  "ACRE",  "ACTA",  "ACTS",  "ADAM",
"ADDS",  "ADEN",  "AFAR",  "AFRO",  "AGEE",  "AHEM",  "AHOY",  "AIDA",
"AIDE",  "AIDS",  "AIRY",  "AJAR",  "AKIN",  "ALAN",  "ALEC",  "ALGA",
"ALIA",  "ALLY",  "ALMA",  "ALOE",  "ALSO",  "ALTO",  "ALUM",  "ALVA",
"AMEN",  "AMES",  "AMID",  "AMMO",  "AMOK",  "AMOS",  "AMRA",  "ANDY",
"ANEW",  "ANNA",  "ANNE",  "ANTE",  "ANTI",  "AQUA",  "ARAB",  "ARCH",
"AREA",  "ARGO",  "ARID",  "ARMY",  "ARTS",  "ARTY",  "ASIA",  "ASKS",
"ATOM",  "AUNT",  "AURA",  "AUTO",  "AVER",  "AVID",  "AVIS",  "AVON",
"AVOW",  "AWAY",  "AWRY",  "BABE",  "BABY",  "BACH",  "BACK",  "BADE",
"BAIL",  "BAIT",  "BAKE",  "BALD",  "BALE",  "BALI",  "BALK",  "BALL",
"BALM",  "BAND",  "BANE",  "BANG",  "BANK",  "BARB",  "BARD",  "BARE",
"BARK",  "BARN",  "BARR",  "BASE",  "BASH",  "BASK",  "BASS",  "BATE",
"BATH",  "BAWD",  "BAWL",  "BEAD",  "BEAK",  "BEAM",  "BEAN",  "BEAR",
"BEAT",  "BEAU",  "BECK",  "BEEF",  "BEEN",  "BEER",  "BEET",  "BELA",
"BELL",  "BELT",  "BEND",  "BENT",  "BERG",  "BERN",  "BERT",  "BESS",
"BEST",  "BETA",  "BETH",  "BHOY",  "BIAS",  "BIDE",  "BIEN",  "BILE",
"BILK",  "BILL",  "BIND",  "BING",  "BIRD",  "BITE",  "BITS",  "BLAB",
"BLAT",  "BLED",  "BLEW",  "BLOB",  "BLOC",  "BLOT",  "BLOW",  "BLUE",
"BLUM",  "BLUR",  "BOAR",  "BOAT",  "BOCA",  "BOCK",  "BODE",  "BODY",
"BOGY",  "BOHR",  "BOIL",  "BOLD",  "BOLO",  "BOLT",  "BOMB",  "BONA",
"BOND",  "BONE",  "BONG",  "BONN",  "BONY",  "BOOK",  "BOOM",  "BOON",
"BOOT",  "BORE",  "BORG",  "BORN",  "BOSE",  "BOSS",  "BOTH",  "BOUT",
"BOWL",  "BOYD",  "BRAD",  "BRAE",  "BRAG",  "BRAN",  "BRAY",  "BRED",
"BREW",  "BRIG",  "BRIM",  "BROW",  "BUCK",  "BUDD",  "BUFF",  "BULB",
"BULK",  "BULL",  "BUNK",  "BUNT",  "BUOY",  "BURG",  "BURL",  "BURN",
"BURR",  "BURT",  "BURY",  "BUSH",  "BUSS",  "BUST",  "BUSY",  "BYTE",
"CADY",  "CAFE",  "CAGE",  "CAIN",  "CAKE",  "CALF",  "CALL",  "CALM",
"CAME",  "CANE",  "CANT",  "CARD",  "CARE",  "CARL",  "CARR",  "CART",
"CASE",  "CASH",  "CASK",  "CAST",  "CAVE",  "CEIL",  "CELL",  "CENT",
"CERN",  "CHAD",  "CHAR",  "CHAT",  "CHAW",  "CHEF",  "CHEN",  "CHEW",
"CHIC",  "CHIN",  "CHOU",  "CHOW",  "CHUB",  "CHUG",  "CHUM",  "CITE",
"CITY",  "CLAD",  "CLAM",  "CLAN",  "CLAW",  "CLAY",  "CLOD",  "CLOG",
"CLOT",  "CLUB",  "CLUE",  "COAL",  "COAT",  "COCA",  "COCK",  "COCO",
"CODA",  "CODE",  "CODY",  "COED",  "COIL",  "COIN",  "COKE",  "COLA",
"COLD",  "COLT",  "COMA",  "COMB",  "COME",  "COOK",  "COOL",  "COON",
"COOT",  "CORD",  "CORE",  "CORK",  "CORN",  "COST",  "COVE",  "COWL",
"CRAB",  "CRAG",  "CRAM",  "CRAY",  "CREW",  "CRIB",  "CROW",  "CRUD",
"CUBA",  "CUBE",  "CUFF",  "CULL",  "CULT",  "CUNY",  "CURB",  "CURD",
"CURE",  "CURL",  "CURT",  "CUTS",  "DADE",  "DALE",  "DAME",  "DANA",
"DANE",  "DANG",  "DANK",  "DARE",  "DARK",  "DARN",  "DART",  "DASH",
"DATA",  "DATE",  "DAVE",  "DAVY",  "DAWN",  "DAYS",  "DEAD",  "DEAF",
"DEAL",  "DEAN",  "DEAR",  "DEBT",  "DECK",  "DEED",  "DEEM",  "DEER",
"DEFT",  "DEFY",  "DELL",  "DENT",  "DENY",  "DESK",  "DIAL",  "DICE",
"DIED",  "DIET",  "DIME",  "DINE",  "DING",  "DINT",  "DIRE",  "DIRT",
"DISC",  "DISH",  "DISK",  "DIVE",  "DOCK",  "DOES",  "DOLE",  "DOLL",
"DOLT",  "DOME",  "DONE",  "DOOM",  "DOOR",  "DORA",  "DOSE",  "DOTE",
"DOUG",  "DOUR",  "DOVE",  "DOWN",  "DRAB",  "DRAG",  "DRAM",  "DRAW",
"DREW",  "DRUB",  "DRUG",  "DRUM",  "DUAL",  "DUCK",  "DUCT",  "DUEL",
"DUET",  "DUKE",  "DULL",  "DUMB",  "DUNE",  "DUNK",  "DUSK",  "DUST",
"DUTY",  "EACH",  "EARL",  "EARN",  "EASE",  "EAST",  "EASY",  "EBEN",
"ECHO",  "EDDY",  "EDEN",  "EDGE",  "EDGY",  "EDIT",  "EDNA",  "EGAN",
"ELAN",  "ELBA",  "ELLA",  "ELSE",  "EMIL",  "EMIT",  "EMMA",  "ENDS",
"ERIC",  "EROS",  "EVEN",  "EVER",  "EVIL",  "EYED",  "FACE",  "FACT",
"FADE",  "FAIL",  "FAIN",  "FAIR",  "FAKE",  "FALL",  "FAME",  "FANG",
"FARM",  "FAST",  "FATE",  "FAWN",  "FEAR",  "FEAT",  "FEED",  "FEEL",
"FEET",  "FELL",  "FELT",  "FEND",  "FERN",  "FEST",  "FEUD",  "FIEF",
"FIGS",  "FILE",  "FILL",  "FILM",  "FIND",  "FINE",  "FINK",  "FIRE",
"FIRM",  "FISH",  "FISK",  "FIST",  "FITS",  "FIVE",  "FLAG",  "FLAK",
"FLAM",  "FLAT",  "FLAW",  "FLEA",  "FLED",  "FLEW",  "FLIT",  "FLOC",
"FLOG",  "FLOW",  "FLUB",  "FLUE",  "FOAL",  "FOAM",  "FOGY",  "FOIL",
"FOLD",  "FOLK",  "FOND",  "FONT",  "FOOD",  "FOOL",  "FOOT",  "FORD",
"FORE",  "FORK",  "FORM",  "FORT",  "FOSS",  "FOUL",  "FOUR",  "FOWL",
"FRAU",  "FRAY",  "FRED",  "FREE",  "FRET",  "FREY",  "FROG",  "FROM",
"FUEL",  "FULL",  "FUME",  "FUND",  "FUNK",  "FURY",  "FUSE",  "FUSS",
"GAFF",  "GAGE",  "GAIL",  "GAIN",  "GAIT",  "GALA",  "GALE",  "GALL",
"GALT",  "GAME",  "GANG",  "GARB",  "GARY",  "GASH",  "GATE",  "GAUL",
"GAUR",  "GAVE",  "GAWK",  "GEAR",  "GELD",  "GENE",  "GENT",  "GERM",
"GETS",  "GIBE",  "GIFT",  "GILD",  "GILL",  "GILT",  "GINA",  "GIRD",
"GIRL",  "GIST",  "GIVE",  "GLAD",  "GLEE",  "GLEN",  "GLIB",  "GLOB",
"GLOM",  "GLOW",  "GLUE",  "GLUM",  "GLUT",  "GOAD",  "GOAL",  "GOAT",
"GOER",  "GOES",  "GOLD",  "GOLF",  "GONE",  "GONG",  "GOOD",  "GOOF",
"GORE",  "GORY",  "GOSH",  "GOUT",  "GOWN",  "GRAB",  "GRAD",  "GRAY",
"GREG",  "GREW",  "GREY",  "GRID",  "GRIM",  "GRIN",  "GRIT",  "GROW",
"GRUB",  "GULF",  "GULL",  "GUNK",  "GURU",  "GUSH",  "GUST",  "GWEN",
"GWYN",  "HAAG",  "HAAS",  "HACK",  "HAIL",  "HAIR",  "HALE",  "HALF",
"HALL",  "HALO",  "HALT",  "HAND",  "HANG",  "HANK",  "HANS",  "HARD",
"HARK",  "HARM",  "HART",  "HASH",  "HAST",  "HATE",  "HATH",  "HAUL",
"HAVE",  "HAWK",  "HAYS",  "HEAD",  "HEAL",  "HEAR",  "HEAT",  "HEBE",
"HECK",  "HEED",  "HEEL",  "HEFT",  "HELD",  "HELL",  "HELM",  "HERB",
"HERD",  "HERE",  "HERO",  "HERS",  "HESS",  "HEWN",  "HICK",  "HIDE",
"HIGH",  "HIKE",  "HILL",  "HILT",  "HIND",  "HINT",  "HIRE",  "HISS",
"HIVE",  "HOBO",  "HOCK",  "HOFF",  "HOLD",  "HOLE",  "HOLM",  "HOLT",
"HOME",  "HONE",  "HONK",  "HOOD",  "HOOF",  "HOOK",  "HOOT",  "HORN",
"HOSE",  "HOST",  "HOUR",  "HOVE",  "HOWE",  "HOWL",  "HOYT",  "HUCK",
"HUED",  "HUFF",  "HUGE",  "HUGH",  "HUGO",  "HULK",  "HULL",  "HUNK",
"HUNT",  "HURD",  "HURL",  "HURT",  "HUSH",  "HYDE",  "HYMN",  "IBIS",
"ICON",  "IDEA",  "IDLE",  "IFFY",  "INCA",  "INCH",  "INTO",  "IONS",
"IOTA",  "IOWA",  "IRIS",  "IRMA",  "IRON",  "ISLE",  "ITCH",  "ITEM",
"IVAN",  "JACK",  "JADE",  "JAIL",  "JAKE",  "JANE",  "JAVA",  "JEAN",
"JEFF",  "JERK",  "JESS",  "JEST",  "JIBE",  "JILL",  "JILT",  "JIVE",
"JOAN",  "JOBS",  "JOCK",  "JOEL",  "JOEY",  "JOHN",  "JOIN",  "JOKE",
"JOLT",  "JOVE",  "JUDD",  "JUDE",  "JUDO",  "JUDY",  "JUJU",  "JUKE",
"JULY",  "JUNE",  "JUNK",  "JUNO",  "JURY",  "JUST",  "JUTE",  "KAHN",
"KALE",  "KANE",  "KANT",  "KARL",  "KATE",  "KEEL",  "KEEN",  "KENO",
"KENT",  "KERN",  "KERR",  "KEYS",  "KICK",  "KILL",  "KIND",  "KING",
"KIRK",  "KISS",  "KITE",  "KLAN",  "KNEE",  "KNEW",  "KNIT",  "KNOB",
"KNOT",  "KNOW",  "KOCH",  "KONG",  "KUDO",  "KURD",  "KURT",  "KYLE",
"LACE",  "LACK",  "LACY",  "LADY",  "LAID",  "LAIN",  "LAIR",  "LAKE",
"LAMB",  "LAME",  "LAND",  "LANE",  "LANG",  "LARD",  "LARK",  "LASS",
"LAST",  "LATE",  "LAUD",  "LAVA",  "LAWN",  "LAWS",  "LAYS",  "LEAD",
"LEAF",  "LEAK",  "LEAN",  "LEAR",  "LEEK",  "LEER",  "LEFT",  "LEND",
"LENS",  "LENT",  "LEON",  "LESK",  "LESS",  "LEST",  "LETS",  "LIAR",
"LICE",  "LICK",  "LIED",  "LIEN",  "LIES",  "LIEU",  "LIFE",  "LIFT",
"LIKE",  "LILA",  "LILT",  "LILY",  "LIMA",  "LIMB",  "LIME",  "LIND",
"LINE",  "LINK",  "LINT",  "LION",  "LISA",  "LIST",  "LIVE",  "LOAD",
"LOAF",  "LOAM",  "LOAN",  "LOCK",  "LOFT",  "LOGE",  "LOIS",  "LOLA",
"LONE",  "LONG",  "LOOK",  "LOON",  "LOOT",  "LORD",  "LORE",  "LOSE",
"LOSS",  "LOST",  "LOUD",  "LOVE",  "LOWE",  "LUCK",  "LUCY",  "LUGE",
"LUKE",  "LULU",  "LUND",  "LUNG",  "LURA",  "LURE",  "LURK",  "LUSH",
"LUST",  "LYLE",  "LYNN",  "LYON",  "LYRA",  "MACE",  "MADE",  "MAGI",
"MAID",  "MAIL",  "MAIN",  "MAKE",  "MALE",  "MALI",  "MALL",  "MALT",
"MANA",  "MANN",  "MANY",  "MARC",  "MARE",  "MARK",  "MARS",  "MART",
"MARY",  "MASH",  "MASK",  "MASS",  "MAST",  "MATE",  "MATH",  "MAUL",
"MAYO",  "MEAD",  "MEAL",  "MEAN",  "MEAT",  "MEEK",  "MEET",  "MELD",
"MELT",  "MEMO",  "MEND",  "MENU",  "MERT",  "MESH",  "MESS",  "MICE",
"MIKE",  "MILD",  "MILE",  "MILK",  "MILL",  "MILT",  "MIMI",  "MIND",
"MINE",  "MINI",  "MINK",  "MINT",  "MIRE",  "MISS",  "MIST",  "MITE",
"MITT",  "MOAN",  "MOAT",  "MOCK",  "MODE",  "MOLD",  "MOLE",  "MOLL",
"MOLT",  "MONA",  "MONK",  "MONT",  "MOOD",  "MOON",  "MOOR",  "MOOT",
"MORE",  "MORN",  "MORT",  "MOSS",  "MOST",  "MOTH",  "MOVE",  "MUCH",
"MUCK",  "MUDD",  "MUFF",  "MULE",  "MULL",  "MURK",  "MUSH",  "MUST",
"MUTE",  "MUTT",  "MYRA",  "MYTH",  "NAGY",  "NAIL",  "NAIR",  "NAME",
"NARY",  "NASH",  "NAVE",  "NAVY",  "NEAL",  "NEAR",  "NEAT",  "NECK",
"NEED",  "NEIL",  "NELL",  "NEON",  "NERO",  "NESS",  "NEST",  "NEWS",
"NEWT",  "NIBS",  "NICE",  "NICK",  "NILE",  "NINA",  "NINE",  "NOAH",
"NODE",  "NOEL",  "NOLL",  "NONE",  "NOOK",  "NOON",  "NORM",  "NOSE",
"NOTE",  "NOUN",  "NOVA",  "NUDE",  "NULL",  "NUMB",  "OATH",  "OBEY",
"OBOE",  "ODIN",  "OHIO",  "OILY",  "OINT",  "OKAY",  "OLAF",  "OLDY",
"OLGA",  "OLIN",  "OMAN",  "OMEN",  "OMIT",  "ONCE",  "ONES",  "ONLY",
"ONTO",  "ONUS",  "ORAL",  "ORGY",  "OSLO",  "OTIS",  "OTTO",  "OUCH",
"OUST",  "OUTS",  "OVAL",  "OVEN",  "OVER",  "OWLY",  "OWNS",  "QUAD",
"QUIT",  "QUOD",  "RACE",  "RACK",  "RACY",  "RAFT",  "RAGE",  "RAID",
"RAIL",  "RAIN",  "RAKE",  "RANK",  "RANT",  "RARE",  "RASH",  "RATE",
"RAVE",  "RAYS",  "READ",  "REAL",  "REAM",  "REAR",  "RECK",  "REED",
"REEF",  "REEK",  "REEL",  "REID",  "REIN",  "RENA",  "REND",  "RENT",
"REST",  "RICE",  "RICH",  "RICK",  "RIDE",  "RIFT",  "RILL",  "RIME",
"RING",  "RINK",  "RISE",  "RISK",  "RITE",  "ROAD",  "ROAM",  "ROAR",
"ROBE",  "ROCK",  "RODE",  "ROIL",  "ROLL",  "ROME",  "ROOD",  "ROOF",
"ROOK",  "ROOM",  "ROOT",  "ROSA",  "ROSE",  "ROSS",  "ROSY",  "ROTH",
"ROUT",  "ROVE",  "ROWE",  "ROWS",  "RUBE",  "RUBY",  "RUDE",  "RUDY",
"RUIN",  "RULE",  "RUNG",  "RUNS",  "RUNT",  "RUSE",  "RUSH",  "RUSK",
"RUSS",  "RUST",  "RUTH",  "SACK",  "SAFE",  "SAGE",  "SAID",  "SAIL",
"SALE",  "SALK",  "SALT",  "SAME",  "SAND",  "SANE",  "SANG",  "SANK",
"SARA",  "SAUL",  "SAVE",  "SAYS",  "SCAN",  "SCAR",  "SCAT",  "SCOT",
"SEAL",  "SEAM",  "SEAR",  "SEAT",  "SEED",  "SEEK",  "SEEM",  "SEEN",
"SEES",  "SELF",  "SELL",  "SEND",  "SENT",  "SETS",  "SEWN",  "SHAG",
"SHAM",  "SHAW",  "SHAY",  "SHED",  "SHIM",  "SHIN",  "SHOD",  "SHOE",
"SHOT",  "SHOW",  "SHUN",  "SHUT",  "SICK",  "SIDE",  "SIFT",  "SIGH",
"SIGN",  "SILK",  "SILL",  "SILO",  "SILT",  "SINE",  "SING",  "SINK",
"SIRE",  "SITE",  "SITS",  "SITU",  "SKAT",  "SKEW",  "SKID",  "SKIM",
"SKIN",  "SKIT",  "SLAB",  "SLAM",  "SLAT",  "SLAY",  "SLED",  "SLEW",
"SLID",  "SLIM",  "SLIT",  "SLOB",  "SLOG",  "SLOT",  "SLOW",  "SLUG",
"SLUM",  "SLUR",  "SMOG",  "SMUG",  "SNAG",  "SNOB",  "SNOW",  "SNUB",
"SNUG",  "SOAK",  "SOAR",  "SOCK",  "SODA",  "SOFA",  "SOFT",  "SOIL",
"SOLD",  "SOME",  "SONG",  "SOON",  "SOOT",  "SORE",  "SORT",  "SOUL",
"SOUR",  "SOWN",  "STAB",  "STAG",  "STAN",  "STAR",  "STAY",  "STEM",
"STEW",  "STIR",  "STOW",  "STUB",  "STUN",  "SUCH",  "SUDS",  "SUIT",
"SULK",  "SUMS",  "SUNG",  "SUNK",  "SURE",  "SURF",  "SWAB",  "SWAG",
"SWAM",  "SWAN",  "SWAT",  "SWAY",  "SWIM",  "SWUM",  "TACK",  "TACT",
"TAIL",  "TAKE",  "TALE",  "TALK",  "TALL",  "TANK",  "TASK",  "TATE",
"TAUT",  "TEAL",  "TEAM",  "TEAR",  "TECH",  "TEEM",  "TEEN",  "TEET",
"TELL",  "TEND",  "TENT",  "TERM",  "TERN",  "TESS",  "TEST",  "THAN",
"THAT",  "THEE",  "THEM",  "THEN",  "THEY",  "THIN",  "THIS",  "THUD",
"THUG",  "TICK",  "TIDE",  "TIDY",  "TIED",  "TIER",  "TILE",  "TILL",
"TILT",  "TIME",  "TINA",  "TINE",  "TINT",  "TINY",  "TIRE",  "TOAD",
"TOGO",  "TOIL",  "TOLD",  "TOLL",  "TONE",  "TONG",  "TONY",  "TOOK",
"TOOL",  "TOOT",  "TORE",  "TORN",  "TOTE",  "TOUR",  "TOUT",  "TOWN",
"TRAG",  "TRAM",  "TRAY",  "TREE",  "TREK",  "TRIG",  "TRIM",  "TRIO",
"TROD",  "TROT",  "TROY",  "TRUE",  "TUBA",  "TUBE",  "TUCK",  "TUFT",
"TUNA",  "TUNE",  "TUNG",  "TURF",  "TURN",  "TUSK",  "TWIG",  "TWIN",
"TWIT",  "ULAN",  "UNIT",  "URGE",  "USED",  "USER",  "USES",  "UTAH",
"VAIL",  "VAIN",  "VALE",  "VARY",  "VASE",  "VAST",  "VEAL",  "VEDA",
"VEIL",  "VEIN",  "VEND",  "VENT",  "VERB",  "VERY",  "VETO",  "VICE",
"VIEW",  "VINE",  "VISE",  "VOID",  "VOLT",  "VOTE",  "WACK",  "WADE",
"WAGE",  "WAIL",  "WAIT",  "WAKE",  "WALE",  "WALK",  "WALL",  "WALT",
"WAND",  "WANE",  "WANG",  "WANT",  "WARD",  "WARM",  "WARN",  "WART",
"WASH",  "WAST",  "WATS",  "WATT",  "WAVE",  "WAVY",  "WAYS",  "WEAK",
"WEAL",  "WEAN",  "WEAR",  "WEED",  "WEEK",  "WEIR",  "WELD",  "WELL",
"WELT",  "WENT",  "WERE",  "WERT",  "WEST",  "WHAM",  "WHAT",  "WHEE",
"WHEN",  "WHET",  "WHOA",  "WHOM",  "WICK",  "WIFE",  "WILD",  "WILL",
"WIND",  "WINE",  "WING",  "WINK",  "WINO",  "WIRE",  "WISE",  "WISH",
"WITH",  "WOLF",  "WONT",  "WOOD",  "WOOL",  "WORD",  "WORE",  "WORK",
"WORM",  "WORN",  "WOVE",  "WRIT",  "WYNN",  "YALE",  "YANG",  "YANK",
"YARD",  "YARN",  "YAWL",  "YAWN",  "YEAH",  "YEAR",  "YELL",  "YOGA",
"YOKE"   };
*/	
/*
private static byte[][] SKEYWords = new byte[][] {
{'A'},{'A','B','E'},{'A','C','E'},{'A','C','T'},{'A','D'},{'A','D','A'},{'A','D','D'},{'A','G','O'},
{'A','I','D'},{'A','I','M'},{'A','I','R'},{'A','L','L'},{'A','L','P'},{'A','M'},{'A','M','Y'},{'A','N'},
{'A','N','A'},{'A','N','D'},{'A','N','N'},{'A','N','T'},{'A','N','Y'},{'A','P','E'},{'A','P','S'},{'A','P','T'},
{'A','R','C'},{'A','R','E'},{'A','R','K'},{'A','R','M'},{'A','R','T'},{'A','S'},{'A','S','H'},{'A','S','K'},
{'A','T'},{'A','T','E'},{'A','U','G'},{'A','U','K'},{'A','V','E'},{'A','W','E'},{'A','W','K'},{'A','W','L'},
{'A','W','N'},{'A','X'},{'A','Y','E'},{'B','A','D'},{'B','A','G'},{'B','A','H'},{'B','A','M'},{'B','A','N'},
{'B','A','R'},{'B','A','T'},{'B','A','Y'},{'B','E'},{'B','E','D'},{'B','E','E'},{'B','E','G'},{'B','E','N'},
{'B','E','T'},{'B','E','Y'},{'B','I','B'},{'B','I','D'},{'B','I','G'},{'B','I','N'},{'B','I','T'},{'B','O','B'},
{'B','O','G'},{'B','O','N'},{'B','O','O'},{'B','O','P'},{'B','O','W'},{'B','O','Y'},{'B','U','B'},{'B','U','D'},
{'B','U','G'},{'B','U','M'},{'B','U','N'},{'B','U','S'},{'B','U','T'},{'B','U','Y'},{'B','Y'},{'B','Y','E'},
{'C','A','B'},{'C','A','L'},{'C','A','M'},{'C','A','N'},{'C','A','P'},{'C','A','R'},{'C','A','T'},{'C','A','W'},
{'C','O','D'},{'C','O','G'},{'C','O','L'},{'C','O','N'},{'C','O','O'},{'C','O','P'},{'C','O','T'},{'C','O','W'},
{'C','O','Y'},{'C','R','Y'},{'C','U','B'},{'C','U','E'},{'C','U','P'},{'C','U','R'},{'C','U','T'},{'D','A','B'},
{'D','A','D'},{'D','A','M'},{'D','A','N'},{'D','A','R'},{'D','A','Y'},{'D','E','E'},{'D','E','L'},{'D','E','N'},
{'D','E','S'},{'D','E','W'},{'D','I','D'},{'D','I','E'},{'D','I','G'},{'D','I','N'},{'D','I','P'},{'D','O'},
{'D','O','E'},{'D','O','G'},{'D','O','N'},{'D','O','T'},{'D','O','W'},{'D','R','Y'},{'D','U','B'},{'D','U','D'},
{'D','U','E'},{'D','U','G'},{'D','U','N'},{'E','A','R'},{'E','A','T'},{'E','D'},{'E','E','L'},{'E','G','G'},
{'E','G','O'},{'E','L','I'},{'E','L','K'},{'E','L','M'},{'E','L','Y'},{'E','M'},{'E','N','D'},{'E','S','T'},
{'E','T','C'},{'E','V','A'},{'E','V','E'},{'E','W','E'},{'E','Y','E'},{'F','A','D'},{'F','A','N'},{'F','A','R'},
{'F','A','T'},{'F','A','Y'},{'F','E','D'},{'F','E','E'},{'F','E','W'},{'F','I','B'},{'F','I','G'},{'F','I','N'},
{'F','I','R'},{'F','I','T'},{'F','L','O'},{'F','L','Y'},{'F','O','E'},{'F','O','G'},{'F','O','R'},{'F','R','Y'},
{'F','U','M'},{'F','U','N'},{'F','U','R'},{'G','A','B'},{'G','A','D'},{'G','A','G'},{'G','A','L'},{'G','A','M'},
{'G','A','P'},{'G','A','S'},{'G','A','Y'},{'G','E','E'},{'G','E','L'},{'G','E','M'},{'G','E','T'},{'G','I','G'},
{'G','I','L'},{'G','I','N'},{'G','O'},{'G','O','T'},{'G','U','M'},{'G','U','N'},{'G','U','S'},{'G','U','T'},
{'G','U','Y'},{'G','Y','M'},{'G','Y','P'},{'H','A'},{'H','A','D'},{'H','A','L'},{'H','A','M'},{'H','A','N'},
{'H','A','P'},{'H','A','S'},{'H','A','T'},{'H','A','W'},{'H','A','Y'},{'H','E'},{'H','E','M'},{'H','E','N'},
{'H','E','R'},{'H','E','W'},{'H','E','Y'},{'H','I'},{'H','I','D'},{'H','I','M'},{'H','I','P'},{'H','I','S'},
{'H','I','T'},{'H','O'},{'H','O','B'},{'H','O','C'},{'H','O','E'},{'H','O','G'},{'H','O','P'},{'H','O','T'},
{'H','O','W'},{'H','U','B'},{'H','U','E'},{'H','U','G'},{'H','U','H'},{'H','U','M'},{'H','U','T'},{'I'},
{'I','C','Y'},{'I','D','A'},{'I','F'},{'I','K','E'},{'I','L','L'},{'I','N','K'},{'I','N','N'},{'I','O'},
{'I','O','N'},{'I','Q'},{'I','R','A'},{'I','R','E'},{'I','R','K'},{'I','S'},{'I','T'},{'I','T','S'},
{'I','V','Y'},{'J','A','B'},{'J','A','G'},{'J','A','M'},{'J','A','N'},{'J','A','R'},{'J','A','W'},{'J','A','Y'},
{'J','E','T'},{'J','I','G'},{'J','I','M'},{'J','O'},{'J','O','B'},{'J','O','E'},{'J','O','G'},{'J','O','T'},
{'J','O','Y'},{'J','U','G'},{'J','U','T'},{'K','A','Y'},{'K','E','G'},{'K','E','N'},{'K','E','Y'},{'K','I','D'},
{'K','I','M'},{'K','I','N'},{'K','I','T'},{'L','A'},{'L','A','B'},{'L','A','C'},{'L','A','D'},{'L','A','G'},
{'L','A','M'},{'L','A','P'},{'L','A','W'},{'L','A','Y'},{'L','E','A'},{'L','E','D'},{'L','E','E'},{'L','E','G'},
{'L','E','N'},{'L','E','O'},{'L','E','T'},{'L','E','W'},{'L','I','D'},{'L','I','E'},{'L','I','N'},{'L','I','P'},
{'L','I','T'},{'L','O'},{'L','O','B'},{'L','O','G'},{'L','O','P'},{'L','O','S'},{'L','O','T'},{'L','O','U'},
{'L','O','W'},{'L','O','Y'},{'L','U','G'},{'L','Y','E'},{'M','A'},{'M','A','C'},{'M','A','D'},{'M','A','E'},
{'M','A','N'},{'M','A','O'},{'M','A','P'},{'M','A','T'},{'M','A','W'},{'M','A','Y'},{'M','E'},{'M','E','G'},
{'M','E','L'},{'M','E','N'},{'M','E','T'},{'M','E','W'},{'M','I','D'},{'M','I','N'},{'M','I','T'},{'M','O','B'},
{'M','O','D'},{'M','O','E'},{'M','O','O'},{'M','O','P'},{'M','O','S'},{'M','O','T'},{'M','O','W'},{'M','U','D'},
{'M','U','G'},{'M','U','M'},{'M','Y'},{'N','A','B'},{'N','A','G'},{'N','A','N'},{'N','A','P'},{'N','A','T'},
{'N','A','Y'},{'N','E'},{'N','E','D'},{'N','E','E'},{'N','E','T'},{'N','E','W'},{'N','I','B'},{'N','I','L'},
{'N','I','P'},{'N','I','T'},{'N','O'},{'N','O','B'},{'N','O','D'},{'N','O','N'},{'N','O','R'},{'N','O','T'},
{'N','O','V'},{'N','O','W'},{'N','U'},{'N','U','N'},{'N','U','T'},{'O'},{'O','A','F'},{'O','A','K'},
{'O','A','R'},{'O','A','T'},{'O','D','D'},{'O','D','E'},{'O','F'},{'O','F','F'},{'O','F','T'},{'O','H'},
{'O','I','L'},{'O','K'},{'O','L','D'},{'O','N'},{'O','N','E'},{'O','R'},{'O','R','B'},{'O','R','E'},
{'O','R','R'},{'O','S'},{'O','T','T'},{'O','U','R'},{'O','U','T'},{'O','V','A'},{'O','W'},{'O','W','E'},
{'O','W','L'},{'O','W','N'},{'O','X'},{'P','A'},{'P','A','D'},{'P','A','L'},{'P','A','M'},{'P','A','N'},
{'P','A','P'},{'P','A','R'},{'P','A','T'},{'P','A','W'},{'P','A','Y'},{'P','E','A'},{'P','E','G'},{'P','E','N'},
{'P','E','P'},{'P','E','R'},{'P','E','T'},{'P','E','W'},{'P','H','I'},{'P','I'},{'P','I','E'},{'P','I','N'},
{'P','I','T'},{'P','L','Y'},{'P','O'},{'P','O','D'},{'P','O','E'},{'P','O','P'},{'P','O','T'},{'P','O','W'},
{'P','R','O'},{'P','R','Y'},{'P','U','B'},{'P','U','G'},{'P','U','N'},{'P','U','P'},{'P','U','T'},{'Q','U','O'},
{'R','A','G'},{'R','A','M'},{'R','A','N'},{'R','A','P'},{'R','A','T'},{'R','A','W'},{'R','A','Y'},{'R','E','B'},
{'R','E','D'},{'R','E','P'},{'R','E','T'},{'R','I','B'},{'R','I','D'},{'R','I','G'},{'R','I','M'},{'R','I','O'},
{'R','I','P'},{'R','O','B'},{'R','O','D'},{'R','O','E'},{'R','O','N'},{'R','O','T'},{'R','O','W'},{'R','O','Y'},
{'R','U','B'},{'R','U','E'},{'R','U','G'},{'R','U','M'},{'R','U','N'},{'R','Y','E'},{'S','A','C'},{'S','A','D'},
{'S','A','G'},{'S','A','L'},{'S','A','M'},{'S','A','N'},{'S','A','P'},{'S','A','T'},{'S','A','W'},{'S','A','Y'},
{'S','E','A'},{'S','E','C'},{'S','E','E'},{'S','E','N'},{'S','E','T'},{'S','E','W'},{'S','H','E'},{'S','H','Y'},
{'S','I','N'},{'S','I','P'},{'S','I','R'},{'S','I','S'},{'S','I','T'},{'S','K','I'},{'S','K','Y'},{'S','L','Y'},
{'S','O'},{'S','O','B'},{'S','O','D'},{'S','O','N'},{'S','O','P'},{'S','O','W'},{'S','O','Y'},{'S','P','A'},
{'S','P','Y'},{'S','U','B'},{'S','U','D'},{'S','U','E'},{'S','U','M'},{'S','U','N'},{'S','U','P'},{'T','A','B'},
{'T','A','D'},{'T','A','G'},{'T','A','N'},{'T','A','P'},{'T','A','R'},{'T','E','A'},{'T','E','D'},{'T','E','E'},
{'T','E','N'},{'T','H','E'},{'T','H','Y'},{'T','I','C'},{'T','I','E'},{'T','I','M'},{'T','I','N'},{'T','I','P'},
{'T','O'},{'T','O','E'},{'T','O','G'},{'T','O','M'},{'T','O','N'},{'T','O','O'},{'T','O','P'},{'T','O','W'},
{'T','O','Y'},{'T','R','Y'},{'T','U','B'},{'T','U','G'},{'T','U','M'},{'T','U','N'},{'T','W','O'},{'U','N'},
{'U','P'},{'U','S'},{'U','S','E'},{'V','A','N'},{'V','A','T'},{'V','E','T'},{'V','I','E'},{'W','A','D'},
{'W','A','G'},{'W','A','R'},{'W','A','S'},{'W','A','Y'},{'W','E'},{'W','E','B'},{'W','E','D'},{'W','E','E'},
{'W','E','T'},{'W','H','O'},{'W','H','Y'},{'W','I','N'},{'W','I','T'},{'W','O','K'},{'W','O','N'},{'W','O','O'},
{'W','O','W'},{'W','R','Y'},{'W','U'},{'Y','A','M'},{'Y','A','P'},{'Y','A','W'},{'Y','E'},{'Y','E','A'},
{'Y','E','S'},{'Y','E','T'},{'Y','O','U'},{'A','B','E','D'},{'A','B','E','L'},{'A','B','E','T'},{'A','B','L','E'},{'A','B','U','T'},
{'A','C','H','E'},{'A','C','I','D'},{'A','C','M','E'},{'A','C','R','E'},{'A','C','T','A'},{'A','C','T','S'},{'A','D','A','M'},{'A','D','D','S'},
{'A','D','E','N'},{'A','F','A','R'},{'A','F','R','O'},{'A','G','E','E'},{'A','H','E','M'},{'A','H','O','Y'},{'A','I','D','A'},{'A','I','D','E'},
{'A','I','D','S'},{'A','I','R','Y'},{'A','J','A','R'},{'A','K','I','N'},{'A','L','A','N'},{'A','L','E','C'},{'A','L','G','A'},{'A','L','I','A'},
{'A','L','L','Y'},{'A','L','M','A'},{'A','L','O','E'},{'A','L','S','O'},{'A','L','T','O'},{'A','L','U','M'},{'A','L','V','A'},{'A','M','E','N'},
{'A','M','E','S'},{'A','M','I','D'},{'A','M','M','O'},{'A','M','O','K'},{'A','M','O','S'},{'A','M','R','A'},{'A','N','D','Y'},{'A','N','E','W'},
{'A','N','N','A'},{'A','N','N','E'},{'A','N','T','E'},{'A','N','T','I'},{'A','Q','U','A'},{'A','R','A','B'},{'A','R','C','H'},{'A','R','E','A'},
{'A','R','G','O'},{'A','R','I','D'},{'A','R','M','Y'},{'A','R','T','S'},{'A','R','T','Y'},{'A','S','I','A'},{'A','S','K','S'},{'A','T','O','M'},
{'A','U','N','T'},{'A','U','R','A'},{'A','U','T','O'},{'A','V','E','R'},{'A','V','I','D'},{'A','V','I','S'},{'A','V','O','N'},{'A','V','O','W'},
{'A','W','A','Y'},{'A','W','R','Y'},{'B','A','B','E'},{'B','A','B','Y'},{'B','A','C','H'},{'B','A','C','K'},{'B','A','D','E'},{'B','A','I','L'},
{'B','A','I','T'},{'B','A','K','E'},{'B','A','L','D'},{'B','A','L','E'},{'B','A','L','I'},{'B','A','L','K'},{'B','A','L','L'},{'B','A','L','M'},
{'B','A','N','D'},{'B','A','N','E'},{'B','A','N','G'},{'B','A','N','K'},{'B','A','R','B'},{'B','A','R','D'},{'B','A','R','E'},{'B','A','R','K'},
{'B','A','R','N'},{'B','A','R','R'},{'B','A','S','E'},{'B','A','S','H'},{'B','A','S','K'},{'B','A','S','S'},{'B','A','T','E'},{'B','A','T','H'},
{'B','A','W','D'},{'B','A','W','L'},{'B','E','A','D'},{'B','E','A','K'},{'B','E','A','M'},{'B','E','A','N'},{'B','E','A','R'},{'B','E','A','T'},
{'B','E','A','U'},{'B','E','C','K'},{'B','E','E','F'},{'B','E','E','N'},{'B','E','E','R'},{'B','E','E','T'},{'B','E','L','A'},{'B','E','L','L'},
{'B','E','L','T'},{'B','E','N','D'},{'B','E','N','T'},{'B','E','R','G'},{'B','E','R','N'},{'B','E','R','T'},{'B','E','S','S'},{'B','E','S','T'},
{'B','E','T','A'},{'B','E','T','H'},{'B','H','O','Y'},{'B','I','A','S'},{'B','I','D','E'},{'B','I','E','N'},{'B','I','L','E'},{'B','I','L','K'},
{'B','I','L','L'},{'B','I','N','D'},{'B','I','N','G'},{'B','I','R','D'},{'B','I','T','E'},{'B','I','T','S'},{'B','L','A','B'},{'B','L','A','T'},
{'B','L','E','D'},{'B','L','E','W'},{'B','L','O','B'},{'B','L','O','C'},{'B','L','O','T'},{'B','L','O','W'},{'B','L','U','E'},{'B','L','U','M'},
{'B','L','U','R'},{'B','O','A','R'},{'B','O','A','T'},{'B','O','C','A'},{'B','O','C','K'},{'B','O','D','E'},{'B','O','D','Y'},{'B','O','G','Y'},
{'B','O','H','R'},{'B','O','I','L'},{'B','O','L','D'},{'B','O','L','O'},{'B','O','L','T'},{'B','O','M','B'},{'B','O','N','A'},{'B','O','N','D'},
{'B','O','N','E'},{'B','O','N','G'},{'B','O','N','N'},{'B','O','N','Y'},{'B','O','O','K'},{'B','O','O','M'},{'B','O','O','N'},{'B','O','O','T'},
{'B','O','R','E'},{'B','O','R','G'},{'B','O','R','N'},{'B','O','S','E'},{'B','O','S','S'},{'B','O','T','H'},{'B','O','U','T'},{'B','O','W','L'},
{'B','O','Y','D'},{'B','R','A','D'},{'B','R','A','E'},{'B','R','A','G'},{'B','R','A','N'},{'B','R','A','Y'},{'B','R','E','D'},{'B','R','E','W'},
{'B','R','I','G'},{'B','R','I','M'},{'B','R','O','W'},{'B','U','C','K'},{'B','U','D','D'},{'B','U','F','F'},{'B','U','L','B'},{'B','U','L','K'},
{'B','U','L','L'},{'B','U','N','K'},{'B','U','N','T'},{'B','U','O','Y'},{'B','U','R','G'},{'B','U','R','L'},{'B','U','R','N'},{'B','U','R','R'},
{'B','U','R','T'},{'B','U','R','Y'},{'B','U','S','H'},{'B','U','S','S'},{'B','U','S','T'},{'B','U','S','Y'},{'B','Y','T','E'},{'C','A','D','Y'},
{'C','A','F','E'},{'C','A','G','E'},{'C','A','I','N'},{'C','A','K','E'},{'C','A','L','F'},{'C','A','L','L'},{'C','A','L','M'},{'C','A','M','E'},
{'C','A','N','E'},{'C','A','N','T'},{'C','A','R','D'},{'C','A','R','E'},{'C','A','R','L'},{'C','A','R','R'},{'C','A','R','T'},{'C','A','S','E'},
{'C','A','S','H'},{'C','A','S','K'},{'C','A','S','T'},{'C','A','V','E'},{'C','E','I','L'},{'C','E','L','L'},{'C','E','N','T'},{'C','E','R','N'},
{'C','H','A','D'},{'C','H','A','R'},{'C','H','A','T'},{'C','H','A','W'},{'C','H','E','F'},{'C','H','E','N'},{'C','H','E','W'},{'C','H','I','C'},
{'C','H','I','N'},{'C','H','O','U'},{'C','H','O','W'},{'C','H','U','B'},{'C','H','U','G'},{'C','H','U','M'},{'C','I','T','E'},{'C','I','T','Y'},
{'C','L','A','D'},{'C','L','A','M'},{'C','L','A','N'},{'C','L','A','W'},{'C','L','A','Y'},{'C','L','O','D'},{'C','L','O','G'},{'C','L','O','T'},
{'C','L','U','B'},{'C','L','U','E'},{'C','O','A','L'},{'C','O','A','T'},{'C','O','C','A'},{'C','O','C','K'},{'C','O','C','O'},{'C','O','D','A'},
{'C','O','D','E'},{'C','O','D','Y'},{'C','O','E','D'},{'C','O','I','L'},{'C','O','I','N'},{'C','O','K','E'},{'C','O','L','A'},{'C','O','L','D'},
{'C','O','L','T'},{'C','O','M','A'},{'C','O','M','B'},{'C','O','M','E'},{'C','O','O','K'},{'C','O','O','L'},{'C','O','O','N'},{'C','O','O','T'},
{'C','O','R','D'},{'C','O','R','E'},{'C','O','R','K'},{'C','O','R','N'},{'C','O','S','T'},{'C','O','V','E'},{'C','O','W','L'},{'C','R','A','B'},
{'C','R','A','G'},{'C','R','A','M'},{'C','R','A','Y'},{'C','R','E','W'},{'C','R','I','B'},{'C','R','O','W'},{'C','R','U','D'},{'C','U','B','A'},
{'C','U','B','E'},{'C','U','F','F'},{'C','U','L','L'},{'C','U','L','T'},{'C','U','N','Y'},{'C','U','R','B'},{'C','U','R','D'},{'C','U','R','E'},
{'C','U','R','L'},{'C','U','R','T'},{'C','U','T','S'},{'D','A','D','E'},{'D','A','L','E'},{'D','A','M','E'},{'D','A','N','A'},{'D','A','N','E'},
{'D','A','N','G'},{'D','A','N','K'},{'D','A','R','E'},{'D','A','R','K'},{'D','A','R','N'},{'D','A','R','T'},{'D','A','S','H'},{'D','A','T','A'},
{'D','A','T','E'},{'D','A','V','E'},{'D','A','V','Y'},{'D','A','W','N'},{'D','A','Y','S'},{'D','E','A','D'},{'D','E','A','F'},{'D','E','A','L'},
{'D','E','A','N'},{'D','E','A','R'},{'D','E','B','T'},{'D','E','C','K'},{'D','E','E','D'},{'D','E','E','M'},{'D','E','E','R'},{'D','E','F','T'},
{'D','E','F','Y'},{'D','E','L','L'},{'D','E','N','T'},{'D','E','N','Y'},{'D','E','S','K'},{'D','I','A','L'},{'D','I','C','E'},{'D','I','E','D'},
{'D','I','E','T'},{'D','I','M','E'},{'D','I','N','E'},{'D','I','N','G'},{'D','I','N','T'},{'D','I','R','E'},{'D','I','R','T'},{'D','I','S','C'},
{'D','I','S','H'},{'D','I','S','K'},{'D','I','V','E'},{'D','O','C','K'},{'D','O','E','S'},{'D','O','L','E'},{'D','O','L','L'},{'D','O','L','T'},
{'D','O','M','E'},{'D','O','N','E'},{'D','O','O','M'},{'D','O','O','R'},{'D','O','R','A'},{'D','O','S','E'},{'D','O','T','E'},{'D','O','U','G'},
{'D','O','U','R'},{'D','O','V','E'},{'D','O','W','N'},{'D','R','A','B'},{'D','R','A','G'},{'D','R','A','M'},{'D','R','A','W'},{'D','R','E','W'},
{'D','R','U','B'},{'D','R','U','G'},{'D','R','U','M'},{'D','U','A','L'},{'D','U','C','K'},{'D','U','C','T'},{'D','U','E','L'},{'D','U','E','T'},
{'D','U','K','E'},{'D','U','L','L'},{'D','U','M','B'},{'D','U','N','E'},{'D','U','N','K'},{'D','U','S','K'},{'D','U','S','T'},{'D','U','T','Y'},
{'E','A','C','H'},{'E','A','R','L'},{'E','A','R','N'},{'E','A','S','E'},{'E','A','S','T'},{'E','A','S','Y'},{'E','B','E','N'},{'E','C','H','O'},
{'E','D','D','Y'},{'E','D','E','N'},{'E','D','G','E'},{'E','D','G','Y'},{'E','D','I','T'},{'E','D','N','A'},{'E','G','A','N'},{'E','L','A','N'},
{'E','L','B','A'},{'E','L','L','A'},{'E','L','S','E'},{'E','M','I','L'},{'E','M','I','T'},{'E','M','M','A'},{'E','N','D','S'},{'E','R','I','C'},
{'E','R','O','S'},{'E','V','E','N'},{'E','V','E','R'},{'E','V','I','L'},{'E','Y','E','D'},{'F','A','C','E'},{'F','A','C','T'},{'F','A','D','E'},
{'F','A','I','L'},{'F','A','I','N'},{'F','A','I','R'},{'F','A','K','E'},{'F','A','L','L'},{'F','A','M','E'},{'F','A','N','G'},{'F','A','R','M'},
{'F','A','S','T'},{'F','A','T','E'},{'F','A','W','N'},{'F','E','A','R'},{'F','E','A','T'},{'F','E','E','D'},{'F','E','E','L'},{'F','E','E','T'},
{'F','E','L','L'},{'F','E','L','T'},{'F','E','N','D'},{'F','E','R','N'},{'F','E','S','T'},{'F','E','U','D'},{'F','I','E','F'},{'F','I','G','S'},
{'F','I','L','E'},{'F','I','L','L'},{'F','I','L','M'},{'F','I','N','D'},{'F','I','N','E'},{'F','I','N','K'},{'F','I','R','E'},{'F','I','R','M'},
{'F','I','S','H'},{'F','I','S','K'},{'F','I','S','T'},{'F','I','T','S'},{'F','I','V','E'},{'F','L','A','G'},{'F','L','A','K'},{'F','L','A','M'},
{'F','L','A','T'},{'F','L','A','W'},{'F','L','E','A'},{'F','L','E','D'},{'F','L','E','W'},{'F','L','I','T'},{'F','L','O','C'},{'F','L','O','G'},
{'F','L','O','W'},{'F','L','U','B'},{'F','L','U','E'},{'F','O','A','L'},{'F','O','A','M'},{'F','O','G','Y'},{'F','O','I','L'},{'F','O','L','D'},
{'F','O','L','K'},{'F','O','N','D'},{'F','O','N','T'},{'F','O','O','D'},{'F','O','O','L'},{'F','O','O','T'},{'F','O','R','D'},{'F','O','R','E'},
{'F','O','R','K'},{'F','O','R','M'},{'F','O','R','T'},{'F','O','S','S'},{'F','O','U','L'},{'F','O','U','R'},{'F','O','W','L'},{'F','R','A','U'},
{'F','R','A','Y'},{'F','R','E','D'},{'F','R','E','E'},{'F','R','E','T'},{'F','R','E','Y'},{'F','R','O','G'},{'F','R','O','M'},{'F','U','E','L'},
{'F','U','L','L'},{'F','U','M','E'},{'F','U','N','D'},{'F','U','N','K'},{'F','U','R','Y'},{'F','U','S','E'},{'F','U','S','S'},{'G','A','F','F'},
{'G','A','G','E'},{'G','A','I','L'},{'G','A','I','N'},{'G','A','I','T'},{'G','A','L','A'},{'G','A','L','E'},{'G','A','L','L'},{'G','A','L','T'},
{'G','A','M','E'},{'G','A','N','G'},{'G','A','R','B'},{'G','A','R','Y'},{'G','A','S','H'},{'G','A','T','E'},{'G','A','U','L'},{'G','A','U','R'},
{'G','A','V','E'},{'G','A','W','K'},{'G','E','A','R'},{'G','E','L','D'},{'G','E','N','E'},{'G','E','N','T'},{'G','E','R','M'},{'G','E','T','S'},
{'G','I','B','E'},{'G','I','F','T'},{'G','I','L','D'},{'G','I','L','L'},{'G','I','L','T'},{'G','I','N','A'},{'G','I','R','D'},{'G','I','R','L'},
{'G','I','S','T'},{'G','I','V','E'},{'G','L','A','D'},{'G','L','E','E'},{'G','L','E','N'},{'G','L','I','B'},{'G','L','O','B'},{'G','L','O','M'},
{'G','L','O','W'},{'G','L','U','E'},{'G','L','U','M'},{'G','L','U','T'},{'G','O','A','D'},{'G','O','A','L'},{'G','O','A','T'},{'G','O','E','R'},
{'G','O','E','S'},{'G','O','L','D'},{'G','O','L','F'},{'G','O','N','E'},{'G','O','N','G'},{'G','O','O','D'},{'G','O','O','F'},{'G','O','R','E'},
{'G','O','R','Y'},{'G','O','S','H'},{'G','O','U','T'},{'G','O','W','N'},{'G','R','A','B'},{'G','R','A','D'},{'G','R','A','Y'},{'G','R','E','G'},
{'G','R','E','W'},{'G','R','E','Y'},{'G','R','I','D'},{'G','R','I','M'},{'G','R','I','N'},{'G','R','I','T'},{'G','R','O','W'},{'G','R','U','B'},
{'G','U','L','F'},{'G','U','L','L'},{'G','U','N','K'},{'G','U','R','U'},{'G','U','S','H'},{'G','U','S','T'},{'G','W','E','N'},{'G','W','Y','N'},
{'H','A','A','G'},{'H','A','A','S'},{'H','A','C','K'},{'H','A','I','L'},{'H','A','I','R'},{'H','A','L','E'},{'H','A','L','F'},{'H','A','L','L'},
{'H','A','L','O'},{'H','A','L','T'},{'H','A','N','D'},{'H','A','N','G'},{'H','A','N','K'},{'H','A','N','S'},{'H','A','R','D'},{'H','A','R','K'},
{'H','A','R','M'},{'H','A','R','T'},{'H','A','S','H'},{'H','A','S','T'},{'H','A','T','E'},{'H','A','T','H'},{'H','A','U','L'},{'H','A','V','E'},
{'H','A','W','K'},{'H','A','Y','S'},{'H','E','A','D'},{'H','E','A','L'},{'H','E','A','R'},{'H','E','A','T'},{'H','E','B','E'},{'H','E','C','K'},
{'H','E','E','D'},{'H','E','E','L'},{'H','E','F','T'},{'H','E','L','D'},{'H','E','L','L'},{'H','E','L','M'},{'H','E','R','B'},{'H','E','R','D'},
{'H','E','R','E'},{'H','E','R','O'},{'H','E','R','S'},{'H','E','S','S'},{'H','E','W','N'},{'H','I','C','K'},{'H','I','D','E'},{'H','I','G','H'},
{'H','I','K','E'},{'H','I','L','L'},{'H','I','L','T'},{'H','I','N','D'},{'H','I','N','T'},{'H','I','R','E'},{'H','I','S','S'},{'H','I','V','E'},
{'H','O','B','O'},{'H','O','C','K'},{'H','O','F','F'},{'H','O','L','D'},{'H','O','L','E'},{'H','O','L','M'},{'H','O','L','T'},{'H','O','M','E'},
{'H','O','N','E'},{'H','O','N','K'},{'H','O','O','D'},{'H','O','O','F'},{'H','O','O','K'},{'H','O','O','T'},{'H','O','R','N'},{'H','O','S','E'},
{'H','O','S','T'},{'H','O','U','R'},{'H','O','V','E'},{'H','O','W','E'},{'H','O','W','L'},{'H','O','Y','T'},{'H','U','C','K'},{'H','U','E','D'},
{'H','U','F','F'},{'H','U','G','E'},{'H','U','G','H'},{'H','U','G','O'},{'H','U','L','K'},{'H','U','L','L'},{'H','U','N','K'},{'H','U','N','T'},
{'H','U','R','D'},{'H','U','R','L'},{'H','U','R','T'},{'H','U','S','H'},{'H','Y','D','E'},{'H','Y','M','N'},{'I','B','I','S'},{'I','C','O','N'},
{'I','D','E','A'},{'I','D','L','E'},{'I','F','F','Y'},{'I','N','C','A'},{'I','N','C','H'},{'I','N','T','O'},{'I','O','N','S'},{'I','O','T','A'},
{'I','O','W','A'},{'I','R','I','S'},{'I','R','M','A'},{'I','R','O','N'},{'I','S','L','E'},{'I','T','C','H'},{'I','T','E','M'},{'I','V','A','N'},
{'J','A','C','K'},{'J','A','D','E'},{'J','A','I','L'},{'J','A','K','E'},{'J','A','N','E'},{'J','A','V','A'},{'J','E','A','N'},{'J','E','F','F'},
{'J','E','R','K'},{'J','E','S','S'},{'J','E','S','T'},{'J','I','B','E'},{'J','I','L','L'},{'J','I','L','T'},{'J','I','V','E'},{'J','O','A','N'},
{'J','O','B','S'},{'J','O','C','K'},{'J','O','E','L'},{'J','O','E','Y'},{'J','O','H','N'},{'J','O','I','N'},{'J','O','K','E'},{'J','O','L','T'},
{'J','O','V','E'},{'J','U','D','D'},{'J','U','D','E'},{'J','U','D','O'},{'J','U','D','Y'},{'J','U','J','U'},{'J','U','K','E'},{'J','U','L','Y'},
{'J','U','N','E'},{'J','U','N','K'},{'J','U','N','O'},{'J','U','R','Y'},{'J','U','S','T'},{'J','U','T','E'},{'K','A','H','N'},{'K','A','L','E'},
{'K','A','N','E'},{'K','A','N','T'},{'K','A','R','L'},{'K','A','T','E'},{'K','E','E','L'},{'K','E','E','N'},{'K','E','N','O'},{'K','E','N','T'},
{'K','E','R','N'},{'K','E','R','R'},{'K','E','Y','S'},{'K','I','C','K'},{'K','I','L','L'},{'K','I','N','D'},{'K','I','N','G'},{'K','I','R','K'},
{'K','I','S','S'},{'K','I','T','E'},{'K','L','A','N'},{'K','N','E','E'},{'K','N','E','W'},{'K','N','I','T'},{'K','N','O','B'},{'K','N','O','T'},
{'K','N','O','W'},{'K','O','C','H'},{'K','O','N','G'},{'K','U','D','O'},{'K','U','R','D'},{'K','U','R','T'},{'K','Y','L','E'},{'L','A','C','E'},
{'L','A','C','K'},{'L','A','C','Y'},{'L','A','D','Y'},{'L','A','I','D'},{'L','A','I','N'},{'L','A','I','R'},{'L','A','K','E'},{'L','A','M','B'},
{'L','A','M','E'},{'L','A','N','D'},{'L','A','N','E'},{'L','A','N','G'},{'L','A','R','D'},{'L','A','R','K'},{'L','A','S','S'},{'L','A','S','T'},
{'L','A','T','E'},{'L','A','U','D'},{'L','A','V','A'},{'L','A','W','N'},{'L','A','W','S'},{'L','A','Y','S'},{'L','E','A','D'},{'L','E','A','F'},
{'L','E','A','K'},{'L','E','A','N'},{'L','E','A','R'},{'L','E','E','K'},{'L','E','E','R'},{'L','E','F','T'},{'L','E','N','D'},{'L','E','N','S'},
{'L','E','N','T'},{'L','E','O','N'},{'L','E','S','K'},{'L','E','S','S'},{'L','E','S','T'},{'L','E','T','S'},{'L','I','A','R'},{'L','I','C','E'},
{'L','I','C','K'},{'L','I','E','D'},{'L','I','E','N'},{'L','I','E','S'},{'L','I','E','U'},{'L','I','F','E'},{'L','I','F','T'},{'L','I','K','E'},
{'L','I','L','A'},{'L','I','L','T'},{'L','I','L','Y'},{'L','I','M','A'},{'L','I','M','B'},{'L','I','M','E'},{'L','I','N','D'},{'L','I','N','E'},
{'L','I','N','K'},{'L','I','N','T'},{'L','I','O','N'},{'L','I','S','A'},{'L','I','S','T'},{'L','I','V','E'},{'L','O','A','D'},{'L','O','A','F'},
{'L','O','A','M'},{'L','O','A','N'},{'L','O','C','K'},{'L','O','F','T'},{'L','O','G','E'},{'L','O','I','S'},{'L','O','L','A'},{'L','O','N','E'},
{'L','O','N','G'},{'L','O','O','K'},{'L','O','O','N'},{'L','O','O','T'},{'L','O','R','D'},{'L','O','R','E'},{'L','O','S','E'},{'L','O','S','S'},
{'L','O','S','T'},{'L','O','U','D'},{'L','O','V','E'},{'L','O','W','E'},{'L','U','C','K'},{'L','U','C','Y'},{'L','U','G','E'},{'L','U','K','E'},
{'L','U','L','U'},{'L','U','N','D'},{'L','U','N','G'},{'L','U','R','A'},{'L','U','R','E'},{'L','U','R','K'},{'L','U','S','H'},{'L','U','S','T'},
{'L','Y','L','E'},{'L','Y','N','N'},{'L','Y','O','N'},{'L','Y','R','A'},{'M','A','C','E'},{'M','A','D','E'},{'M','A','G','I'},{'M','A','I','D'},
{'M','A','I','L'},{'M','A','I','N'},{'M','A','K','E'},{'M','A','L','E'},{'M','A','L','I'},{'M','A','L','L'},{'M','A','L','T'},{'M','A','N','A'},
{'M','A','N','N'},{'M','A','N','Y'},{'M','A','R','C'},{'M','A','R','E'},{'M','A','R','K'},{'M','A','R','S'},{'M','A','R','T'},{'M','A','R','Y'},
{'M','A','S','H'},{'M','A','S','K'},{'M','A','S','S'},{'M','A','S','T'},{'M','A','T','E'},{'M','A','T','H'},{'M','A','U','L'},{'M','A','Y','O'},
{'M','E','A','D'},{'M','E','A','L'},{'M','E','A','N'},{'M','E','A','T'},{'M','E','E','K'},{'M','E','E','T'},{'M','E','L','D'},{'M','E','L','T'},
{'M','E','M','O'},{'M','E','N','D'},{'M','E','N','U'},{'M','E','R','T'},{'M','E','S','H'},{'M','E','S','S'},{'M','I','C','E'},{'M','I','K','E'},
{'M','I','L','D'},{'M','I','L','E'},{'M','I','L','K'},{'M','I','L','L'},{'M','I','L','T'},{'M','I','M','I'},{'M','I','N','D'},{'M','I','N','E'},
{'M','I','N','I'},{'M','I','N','K'},{'M','I','N','T'},{'M','I','R','E'},{'M','I','S','S'},{'M','I','S','T'},{'M','I','T','E'},{'M','I','T','T'},
{'M','O','A','N'},{'M','O','A','T'},{'M','O','C','K'},{'M','O','D','E'},{'M','O','L','D'},{'M','O','L','E'},{'M','O','L','L'},{'M','O','L','T'},
{'M','O','N','A'},{'M','O','N','K'},{'M','O','N','T'},{'M','O','O','D'},{'M','O','O','N'},{'M','O','O','R'},{'M','O','O','T'},{'M','O','R','E'},
{'M','O','R','N'},{'M','O','R','T'},{'M','O','S','S'},{'M','O','S','T'},{'M','O','T','H'},{'M','O','V','E'},{'M','U','C','H'},{'M','U','C','K'},
{'M','U','D','D'},{'M','U','F','F'},{'M','U','L','E'},{'M','U','L','L'},{'M','U','R','K'},{'M','U','S','H'},{'M','U','S','T'},{'M','U','T','E'},
{'M','U','T','T'},{'M','Y','R','A'},{'M','Y','T','H'},{'N','A','G','Y'},{'N','A','I','L'},{'N','A','I','R'},{'N','A','M','E'},{'N','A','R','Y'},
{'N','A','S','H'},{'N','A','V','E'},{'N','A','V','Y'},{'N','E','A','L'},{'N','E','A','R'},{'N','E','A','T'},{'N','E','C','K'},{'N','E','E','D'},
{'N','E','I','L'},{'N','E','L','L'},{'N','E','O','N'},{'N','E','R','O'},{'N','E','S','S'},{'N','E','S','T'},{'N','E','W','S'},{'N','E','W','T'},
{'N','I','B','S'},{'N','I','C','E'},{'N','I','C','K'},{'N','I','L','E'},{'N','I','N','A'},{'N','I','N','E'},{'N','O','A','H'},{'N','O','D','E'},
{'N','O','E','L'},{'N','O','L','L'},{'N','O','N','E'},{'N','O','O','K'},{'N','O','O','N'},{'N','O','R','M'},{'N','O','S','E'},{'N','O','T','E'},
{'N','O','U','N'},{'N','O','V','A'},{'N','U','D','E'},{'N','U','L','L'},{'N','U','M','B'},{'O','A','T','H'},{'O','B','E','Y'},{'O','B','O','E'},
{'O','D','I','N'},{'O','H','I','O'},{'O','I','L','Y'},{'O','I','N','T'},{'O','K','A','Y'},{'O','L','A','F'},{'O','L','D','Y'},{'O','L','G','A'},
{'O','L','I','N'},{'O','M','A','N'},{'O','M','E','N'},{'O','M','I','T'},{'O','N','C','E'},{'O','N','E','S'},{'O','N','L','Y'},{'O','N','T','O'},
{'O','N','U','S'},{'O','R','A','L'},{'O','R','G','Y'},{'O','S','L','O'},{'O','T','I','S'},{'O','T','T','O'},{'O','U','C','H'},{'O','U','S','T'},
{'O','U','T','S'},{'O','V','A','L'},{'O','V','E','N'},{'O','V','E','R'},{'O','W','L','Y'},{'O','W','N','S'},{'Q','U','A','D'},{'Q','U','I','T'},
{'Q','U','O','D'},{'R','A','C','E'},{'R','A','C','K'},{'R','A','C','Y'},{'R','A','F','T'},{'R','A','G','E'},{'R','A','I','D'},{'R','A','I','L'},
{'R','A','I','N'},{'R','A','K','E'},{'R','A','N','K'},{'R','A','N','T'},{'R','A','R','E'},{'R','A','S','H'},{'R','A','T','E'},{'R','A','V','E'},
{'R','A','Y','S'},{'R','E','A','D'},{'R','E','A','L'},{'R','E','A','M'},{'R','E','A','R'},{'R','E','C','K'},{'R','E','E','D'},{'R','E','E','F'},
{'R','E','E','K'},{'R','E','E','L'},{'R','E','I','D'},{'R','E','I','N'},{'R','E','N','A'},{'R','E','N','D'},{'R','E','N','T'},{'R','E','S','T'},
{'R','I','C','E'},{'R','I','C','H'},{'R','I','C','K'},{'R','I','D','E'},{'R','I','F','T'},{'R','I','L','L'},{'R','I','M','E'},{'R','I','N','G'},
{'R','I','N','K'},{'R','I','S','E'},{'R','I','S','K'},{'R','I','T','E'},{'R','O','A','D'},{'R','O','A','M'},{'R','O','A','R'},{'R','O','B','E'},
{'R','O','C','K'},{'R','O','D','E'},{'R','O','I','L'},{'R','O','L','L'},{'R','O','M','E'},{'R','O','O','D'},{'R','O','O','F'},{'R','O','O','K'},
{'R','O','O','M'},{'R','O','O','T'},{'R','O','S','A'},{'R','O','S','E'},{'R','O','S','S'},{'R','O','S','Y'},{'R','O','T','H'},{'R','O','U','T'},
{'R','O','V','E'},{'R','O','W','E'},{'R','O','W','S'},{'R','U','B','E'},{'R','U','B','Y'},{'R','U','D','E'},{'R','U','D','Y'},{'R','U','I','N'},
{'R','U','L','E'},{'R','U','N','G'},{'R','U','N','S'},{'R','U','N','T'},{'R','U','S','E'},{'R','U','S','H'},{'R','U','S','K'},{'R','U','S','S'},
{'R','U','S','T'},{'R','U','T','H'},{'S','A','C','K'},{'S','A','F','E'},{'S','A','G','E'},{'S','A','I','D'},{'S','A','I','L'},{'S','A','L','E'},
{'S','A','L','K'},{'S','A','L','T'},{'S','A','M','E'},{'S','A','N','D'},{'S','A','N','E'},{'S','A','N','G'},{'S','A','N','K'},{'S','A','R','A'},
{'S','A','U','L'},{'S','A','V','E'},{'S','A','Y','S'},{'S','C','A','N'},{'S','C','A','R'},{'S','C','A','T'},{'S','C','O','T'},{'S','E','A','L'},
{'S','E','A','M'},{'S','E','A','R'},{'S','E','A','T'},{'S','E','E','D'},{'S','E','E','K'},{'S','E','E','M'},{'S','E','E','N'},{'S','E','E','S'},
{'S','E','L','F'},{'S','E','L','L'},{'S','E','N','D'},{'S','E','N','T'},{'S','E','T','S'},{'S','E','W','N'},{'S','H','A','G'},{'S','H','A','M'},
{'S','H','A','W'},{'S','H','A','Y'},{'S','H','E','D'},{'S','H','I','M'},{'S','H','I','N'},{'S','H','O','D'},{'S','H','O','E'},{'S','H','O','T'},
{'S','H','O','W'},{'S','H','U','N'},{'S','H','U','T'},{'S','I','C','K'},{'S','I','D','E'},{'S','I','F','T'},{'S','I','G','H'},{'S','I','G','N'},
{'S','I','L','K'},{'S','I','L','L'},{'S','I','L','O'},{'S','I','L','T'},{'S','I','N','E'},{'S','I','N','G'},{'S','I','N','K'},{'S','I','R','E'},
{'S','I','T','E'},{'S','I','T','S'},{'S','I','T','U'},{'S','K','A','T'},{'S','K','E','W'},{'S','K','I','D'},{'S','K','I','M'},{'S','K','I','N'},
{'S','K','I','T'},{'S','L','A','B'},{'S','L','A','M'},{'S','L','A','T'},{'S','L','A','Y'},{'S','L','E','D'},{'S','L','E','W'},{'S','L','I','D'},
{'S','L','I','M'},{'S','L','I','T'},{'S','L','O','B'},{'S','L','O','G'},{'S','L','O','T'},{'S','L','O','W'},{'S','L','U','G'},{'S','L','U','M'},
{'S','L','U','R'},{'S','M','O','G'},{'S','M','U','G'},{'S','N','A','G'},{'S','N','O','B'},{'S','N','O','W'},{'S','N','U','B'},{'S','N','U','G'},
{'S','O','A','K'},{'S','O','A','R'},{'S','O','C','K'},{'S','O','D','A'},{'S','O','F','A'},{'S','O','F','T'},{'S','O','I','L'},{'S','O','L','D'},
{'S','O','M','E'},{'S','O','N','G'},{'S','O','O','N'},{'S','O','O','T'},{'S','O','R','E'},{'S','O','R','T'},{'S','O','U','L'},{'S','O','U','R'},
{'S','O','W','N'},{'S','T','A','B'},{'S','T','A','G'},{'S','T','A','N'},{'S','T','A','R'},{'S','T','A','Y'},{'S','T','E','M'},{'S','T','E','W'},
{'S','T','I','R'},{'S','T','O','W'},{'S','T','U','B'},{'S','T','U','N'},{'S','U','C','H'},{'S','U','D','S'},{'S','U','I','T'},{'S','U','L','K'},
{'S','U','M','S'},{'S','U','N','G'},{'S','U','N','K'},{'S','U','R','E'},{'S','U','R','F'},{'S','W','A','B'},{'S','W','A','G'},{'S','W','A','M'},
{'S','W','A','N'},{'S','W','A','T'},{'S','W','A','Y'},{'S','W','I','M'},{'S','W','U','M'},{'T','A','C','K'},{'T','A','C','T'},{'T','A','I','L'},
{'T','A','K','E'},{'T','A','L','E'},{'T','A','L','K'},{'T','A','L','L'},{'T','A','N','K'},{'T','A','S','K'},{'T','A','T','E'},{'T','A','U','T'},
{'T','E','A','L'},{'T','E','A','M'},{'T','E','A','R'},{'T','E','C','H'},{'T','E','E','M'},{'T','E','E','N'},{'T','E','E','T'},{'T','E','L','L'},
{'T','E','N','D'},{'T','E','N','T'},{'T','E','R','M'},{'T','E','R','N'},{'T','E','S','S'},{'T','E','S','T'},{'T','H','A','N'},{'T','H','A','T'},
{'T','H','E','E'},{'T','H','E','M'},{'T','H','E','N'},{'T','H','E','Y'},{'T','H','I','N'},{'T','H','I','S'},{'T','H','U','D'},{'T','H','U','G'},
{'T','I','C','K'},{'T','I','D','E'},{'T','I','D','Y'},{'T','I','E','D'},{'T','I','E','R'},{'T','I','L','E'},{'T','I','L','L'},{'T','I','L','T'},
{'T','I','M','E'},{'T','I','N','A'},{'T','I','N','E'},{'T','I','N','T'},{'T','I','N','Y'},{'T','I','R','E'},{'T','O','A','D'},{'T','O','G','O'},
{'T','O','I','L'},{'T','O','L','D'},{'T','O','L','L'},{'T','O','N','E'},{'T','O','N','G'},{'T','O','N','Y'},{'T','O','O','K'},{'T','O','O','L'},
{'T','O','O','T'},{'T','O','R','E'},{'T','O','R','N'},{'T','O','T','E'},{'T','O','U','R'},{'T','O','U','T'},{'T','O','W','N'},{'T','R','A','G'},
{'T','R','A','M'},{'T','R','A','Y'},{'T','R','E','E'},{'T','R','E','K'},{'T','R','I','G'},{'T','R','I','M'},{'T','R','I','O'},{'T','R','O','D'},
{'T','R','O','T'},{'T','R','O','Y'},{'T','R','U','E'},{'T','U','B','A'},{'T','U','B','E'},{'T','U','C','K'},{'T','U','F','T'},{'T','U','N','A'},
{'T','U','N','E'},{'T','U','N','G'},{'T','U','R','F'},{'T','U','R','N'},{'T','U','S','K'},{'T','W','I','G'},{'T','W','I','N'},{'T','W','I','T'},
{'U','L','A','N'},{'U','N','I','T'},{'U','R','G','E'},{'U','S','E','D'},{'U','S','E','R'},{'U','S','E','S'},{'U','T','A','H'},{'V','A','I','L'},
{'V','A','I','N'},{'V','A','L','E'},{'V','A','R','Y'},{'V','A','S','E'},{'V','A','S','T'},{'V','E','A','L'},{'V','E','D','A'},{'V','E','I','L'},
{'V','E','I','N'},{'V','E','N','D'},{'V','E','N','T'},{'V','E','R','B'},{'V','E','R','Y'},{'V','E','T','O'},{'V','I','C','E'},{'V','I','E','W'},
{'V','I','N','E'},{'V','I','S','E'},{'V','O','I','D'},{'V','O','L','T'},{'V','O','T','E'},{'W','A','C','K'},{'W','A','D','E'},{'W','A','G','E'},
{'W','A','I','L'},{'W','A','I','T'},{'W','A','K','E'},{'W','A','L','E'},{'W','A','L','K'},{'W','A','L','L'},{'W','A','L','T'},{'W','A','N','D'},
{'W','A','N','E'},{'W','A','N','G'},{'W','A','N','T'},{'W','A','R','D'},{'W','A','R','M'},{'W','A','R','N'},{'W','A','R','T'},{'W','A','S','H'},
{'W','A','S','T'},{'W','A','T','S'},{'W','A','T','T'},{'W','A','V','E'},{'W','A','V','Y'},{'W','A','Y','S'},{'W','E','A','K'},{'W','E','A','L'},
{'W','E','A','N'},{'W','E','A','R'},{'W','E','E','D'},{'W','E','E','K'},{'W','E','I','R'},{'W','E','L','D'},{'W','E','L','L'},{'W','E','L','T'},
{'W','E','N','T'},{'W','E','R','E'},{'W','E','R','T'},{'W','E','S','T'},{'W','H','A','M'},{'W','H','A','T'},{'W','H','E','E'},{'W','H','E','N'},
{'W','H','E','T'},{'W','H','O','A'},{'W','H','O','M'},{'W','I','C','K'},{'W','I','F','E'},{'W','I','L','D'},{'W','I','L','L'},{'W','I','N','D'},
{'W','I','N','E'},{'W','I','N','G'},{'W','I','N','K'},{'W','I','N','O'},{'W','I','R','E'},{'W','I','S','E'},{'W','I','S','H'},{'W','I','T','H'},
{'W','O','L','F'},{'W','O','N','T'},{'W','O','O','D'},{'W','O','O','L'},{'W','O','R','D'},{'W','O','R','E'},{'W','O','R','K'},{'W','O','R','M'},
{'W','O','R','N'},{'W','O','V','E'},{'W','R','I','T'},{'W','Y','N','N'},{'Y','A','L','E'},{'Y','A','N','G'},{'Y','A','N','K'},{'Y','A','R','D'},
{'Y','A','R','N'},{'Y','A','W','L'},{'Y','A','W','N'},{'Y','E','A','H'},{'Y','E','A','R'},{'Y','E','L','L'},{'Y','O','G','A'},{'Y','O','K','E'},
};
*/

	// default constructor
	public ParanoiaOTP()
	{
		init();
	}
	
	// advanced constructor
	public ParanoiaOTP(String seed, String pass, int seq, int hash)
	{
		init();
		
		setSeed(seed);
		setPassPhrase(pass);
		setSequence(seq);
		setHashType(hash);
	}

	/*
	 *		basic init for class
	 */
	private void init()
	{
		int i;
		
	
		CurrentKey = new byte[8];
		// init with simple sequence
		for (i = 0; i < 8; i++) {
			CurrentKey[i] = 0;
		}
		
		Sequence = 0x0FFFFFFF;
		HashType = 99;
		
		filled = false;
	}
	
	/*
	 *		set the hash function type
	 *		0 = MD5, 1 = MD4, 2 = SHA-1
	 */
	public boolean setHashType(int hash)
	{
		if (hash >= 0 && hash <= 2) {
			HashType = hash;
			// signal recalculation
			filled = false;
			return(true);
		}
		return(false);
	}
	
	/*
	 *		set the seed
	 */
	public boolean setSeed(String seed)
	{
		char[] testSeed;
		int i;
		String tmp;
		
		
		if (seed.length() >= 1 && seed.length() <= 16) {
			tmp = seed.toLowerCase();
		
			testSeed = tmp.toCharArray();
			for (i = 0; i < testSeed.length; i++) {
				if (!Character.isDigit(testSeed[i])) {
					if (!Character.isLowerCase(testSeed[i])) {
						return(false);
					}
				}
			}
			
			Seed = new String(tmp);
			// signal recalculation
			filled = false;
			return(true);
		}
		return(false);
	}

	/*
	 *		set secret passphrase
	 */
	public boolean setPassPhrase(String pass)
	{
		if (pass.length() >= 10 && pass.length() <= 63) {
			PassPhrase = new String(pass);
			// signal recalculation
			filled = false;
			return(true);
		}
		return(false);
	}
	
	/*
	 *		set the sequence number
	 */
	public boolean setSequence(int seq)
	{
		if (seq >= 0) {
			Sequence = seq;
			// signal recalculation
			filled = false;
			return(true);
		}
		return(false);
	}
	
	/*
	 *		generate current key
	 */
	private void genOTP()
	{
		String tmp;
		byte[] hashInput;
		byte[] tmpHash;
		IMessageDigest HashFunct;
		int i, n, inputLength;
		

		// check if all values are initilized
		if (Seed != null || PassPhrase != null || HashType != 99 || Sequence != 0x0FFFFFFF) {
		
		// concat Seed and PassPhrase
		tmp = new String(Seed);
		tmp = tmp.concat(PassPhrase);
		
		// setup input for hashing function
		tmpHash = tmp.getBytes();
		inputLength = tmpHash.length;
		hashInput = new byte[((inputLength < 8) ? 8 : inputLength)];
		System.arraycopy(tmpHash, 0, hashInput, 0, inputLength);

		switch (HashType) {
		case 0:
			HashFunct = new MD5();
			for (n = 0; n <= Sequence; n++) {		
				HashFunct.update(hashInput, 0, inputLength);
				tmpHash = HashFunct.digest();
				// folding to make 64 bits out of 128
				for (i = 0; i < 8; i++) {
					hashInput[i] = (byte) (tmpHash[i] ^ tmpHash[i+8]);
				}
				// after the initial step we only use 64 bits
				inputLength = 8;
			}
			break;
		case 1:
			HashFunct = new MD4();
			for (n = 0; n <= Sequence; n++) {		
				HashFunct.update(hashInput, 0, inputLength);
				tmpHash = HashFunct.digest();
				// folding to make 64 bits out of 128
				for (i = 0; i < 8; i++) {
					hashInput[i] = (byte) (tmpHash[i] ^ tmpHash[i+8]);
				}				
				// after the initial step we only use 64 bits
				inputLength = 8;
			}
			break;
		case 2:
			HashFunct = new Sha160();
			for (n = 0; n <= Sequence; n++) {		
				HashFunct.update(hashInput, 0, inputLength);
				tmpHash = HashFunct.digest();
				// folding to make 64 bits out of 160
				for (i = 0; i < 8; i++) {
					hashInput[i] = (byte) (tmpHash[i] ^ tmpHash[i+8]);
				}
				for (i = 0; i < 4; i++) {
					hashInput[i] = (byte) (hashInput[i] ^ tmpHash[i+16]);
				}
				// after the initial step we only use 64 bits
				inputLength = 8;
			}
			break;
		}
		// return generated to to system
		System.arraycopy(hashInput, 0, CurrentKey, 0, 8);
		
		// signal a calculated key
		filled = true;
		
		}
	}

	/*
	 *		generate hex output (four 4 letter packs)
	 */
	public String getHexOTP()
	{
		String tmp, out = new String("");
		int i;
				
	
		if (!filled) genOTP();
		
		tmp = Util.toString(CurrentKey, 0, 8);
		
		for (i = 0; i < 4; i++) {
			out = out.concat(tmp.substring(i*4, (i*4)+4));
			out = out.concat(" ");
		}
		
		return(out.trim());
	}

	/*
	 *		generate the 6 word output
	 */	
	public String getWordsOTP()
	{
		int i;
		byte sum;
		String wordKey;
		short[] w = new short[6];
		byte[] key = new byte[9];
		
		
		if (!filled) genOTP();
		
		System.arraycopy(CurrentKey, 0, key, 0, 8);
		
		// calculate OTP checksum
		sum = 0;
		for (i = 0; i < 8; i++) {
			sum += (key[i] >>> 6) & 0x03;
			sum += (key[i] >>> 4) & 0x03;
			sum += (key[i] >>> 2) & 0x03;
			sum += key[i] & 0x03;
		}
		key[8] = (byte) (sum << 6);


	   w[0] = (short) ((short) key[0] & 0x00ff);
		w[0] = (short) ((w[0] << 3) | ((short) (key[1] >>> 5) & 0x0007));

//		System.out.println("w0: " + w[0] + " word: " + SKEYWords[w[0]]);

		w[1] = (short) ((short) (key[1] << 3) & 0x00f8);
		w[1] = (short) ((w[1] << 3) | ((short) (key[2] >>> 2) & 0x003f));
		
//		System.out.println("w1: " + w[1] + " word: " + SKEYWords[w[1]]);

		w[2] = (short) ((short) (key[2] << 6) & 0x00ff);
		w[2] = (short) ((w[2] << 2) | ((short) key[3] & 0x00ff));
		w[2] = (short) ((w[2] << 1) | ((short) (key[4] >>> 7) & 0x0001));
		
//		System.out.println("w2: " + w[2] + " word: " + SKEYWords[w[2]]);
		
		w[3] = (short) ((short) (key[4] << 1) & 0x00ff);
		w[3] = (short) ((w[3] << 3) | ((short) (key[5] >>> 4) & 0x000f));
		
//		System.out.println("w3: " + w[3] + " word: " + SKEYWords[w[3]]);
		
		w[4] = (short) ((short) (key[5] << 4) & 0x00f0);
		w[4] = (short) ((w[4] << 3) | ((short) (key[6] >>> 1) & 0x007f));
		
//		System.out.println("w4: " + w[4] + " word: " + SKEYWords[w[4]]);
		
		w[5] = (short) ((short) key[6] & 0x01);
		w[5] = (short) ((w[5] << 8) | ((short) key[7] & 0x00ff));
		w[5] = (short) ((w[5] << 2) | ((short) (key[8] >>> 6) & 0x0003));
		
//		System.out.println("w5: " + w[5] + " word: " + SKEYWords[w[5]]);

		return(new String(SKEYWords[w[0]] + " " +
								SKEYWords[w[1]] + " " +
								SKEYWords[w[2]] + " " +
								SKEYWords[w[3]] + " " +
								SKEYWords[w[4]] + " " +
								SKEYWords[w[5]]));
								
/*								
		byte[] out = new byte[(4*6)+5];
		int pos;
		
		pos = 0;
		for (i = 0; i < 6; i++) {
			System.arraycopy(SKEYWords[w[i]], 0, out, pos, SKEYWords[w[i]].length);
			pos += SKEYWords[w[i]].length;
			if (i != 5) out[pos] = ' ';
			pos++;
		}
		return(new String(out)); */
	}
	
/*	public void testWords()
	{
		int i;
	
		if (SKEYWords.length != SKEYWords2.length) System.out.println("table size dosn't match");
		else {
			for (i = 0; i < SKEYWords.length; i++) {
				if (SKEYWords[i].compareTo(SKEYWords2[i]) != 0) {
					System.out.println("Different Words found at " + i + " words are: " + SKEYWords[i] + " and " + SKEYWords2[i]);
				}
			}
		}
	}
*/

/*	public void printAsByteArrays()
	{
		int i, i2, l = 0;
	
		System.out.println("{");
		for (i = 0; i < SKEYWords.length; i++) {
			System.out.print("{");
			for (i2 = 0; i2 < SKEYWords[i].length(); i2++) {
				System.out.print("'" + SKEYWords[i].charAt(i2) + "'");
				if (i2+1 == SKEYWords[i].length()) System.out.print("}");
				else System.out.print(",");
			}
			System.out.print(",");
			l++;
			if (l == 8) { l = 0; System.out.println(""); }
		}
		System.out.println("}");
	}
*/

/*
	public void printASManyClasses()
	{
		int i, i2, curStart, curEnd, l;
		int numCs = (SKEYWords.length / 100) + 1;
		java.io.FileOutputStream out;
		String start = new String (	"package org.mulliner.paranoia;\n\n" +
												"public class Word");
		String next = new String (	" implements saveSpace\n" +
										 	"{\n\n");
		
		String end = new String (	"\n\tpublic String getWord(int index)" +
											"\t{\n" +
											"\t\tif (index >= 0 && index < Words.length) {\n" +
											"\t\t\treturn(Words[index]);\n" +
											"\t\t}\n" + 
											"\t\telse return(null);\n" +
											"\t}\n}\n");

		
		for (i2 = 0; i2 < numCs; i2++) {
			try {
			out = new java.io.FileOutputStream("Word" + (i2*100) + ".java");  

		
			out.write(start.getBytes());
			out.write(String.valueOf(i2*100).getBytes());
			out.write(next.getBytes());
					
			out.write("private static String[] Words = new String[] {".getBytes());
			
			curStart = i2*100;
			curEnd = curStart + 100;
			l = 0;
			
			for (i = curStart; i < curEnd; i++) {
				if (i >= SKEYWords.length) { break; }
				out.write(new String("\"" + SKEYWords[i] + "\"").getBytes());
				if (i+1 == curEnd || i+1 == SKEYWords.length) out.write(' ');
				else out.write(", ".getBytes());
				l++;
				if (l == 8) { l = 0; out.write('\n'); }
			}
			out.write("};\n".getBytes());
			
			out.write(end.getBytes());
			
			out.close();
			
			}catch (java.io.IOException ioe) {}
		}
		
		

	}
*/
}

